# ACT I

### SCENE I. London. The Parliament-house.
  
_Alarum. Enter YORK, EDWARD, RICHARD, NORFOLK, MONTAGUE, WARWICK, and
Soldiers_

**WARWICK**  
I wonder how the king escaped our hands.  

**YORK**  
While we pursued the horsemen of the north,  
He slily stole away and left his men:  
Whereat the great Lord of Northumberland,  
Whose warlike ears could never brook retreat,  
Cheer'd up the drooping army; and himself,  
Lord Clifford and Lord Stafford, all abreast,  
Charged our main battle's front, and breaking in  
Were by the swords of common soldiers slain.  

**EDWARD**  
Lord Stafford's father, Duke of Buckingham,  
Is either slain or wounded dangerously;  
I cleft his beaver with a downright blow:  
That this is true, father, behold his blood.  

**MONTAGUE**  
And, brother, here's the Earl of Wiltshire's blood,  
Whom I encounter'd as the battles join'd.  

**RICHARD**  
Speak thou for me and tell them what I did.  

_Throwing down SOMERSET 's head_

**YORK**  
Richard hath best deserved of all my sons.  
But is your grace dead, my Lord of Somerset?  

**NORFOLK**  
Such hope have all the line of John of Gaunt!  

**RICHARD**  
Thus do I hope to shake King Henry's head.  

**WARWICK**  
And so do I. Victorious Prince of York,  
Before I see thee seated in that throne  
Which now the house of Lancaster usurps,  
I vow by heaven these eyes shall never close.  
This is the palace of the fearful king,  
And this the regal seat: possess it, York;  
For this is thine and not King Henry's heirs'  

**YORK**  
Assist me, then, sweet Warwick, and I will;  
For hither we have broken in by force.  

**NORFOLK**  
We'll all assist you; he that flies shall die.  

**YORK**  
Thanks, gentle Norfolk: stay by me, my lords;  
And, soldiers, stay and lodge by me this night.  

_They go up_

**WARWICK**  
And when the king comes, offer no violence,  
Unless he seek to thrust you out perforce.  

**YORK**  
The queen this day here holds her parliament,  
But little thinks we shall be of her council:  
By words or blows here let us win our right.  

**RICHARD**  
Arm'd as we are, let's stay within this house.  

**WARWICK**  
The bloody parliament shall this be call'd,  
Unless Plantagenet, Duke of York, be king,  
And bashful Henry deposed, whose cowardice  
Hath made us by-words to our enemies.  

**YORK**  
Then leave me not, my lords; be resolute;  
I mean to take possession of my right.  

**WARWICK**  
Neither the king, nor he that loves him best,  
The proudest he that holds up Lancaster,  
Dares stir a wing, if Warwick shake his bells.  
I'll plant Plantagenet, root him up who dares:  
Resolve thee, Richard; claim the English crown.  

_Flourish. Enter KING HENRY VI, CLIFFORD, NORTHUMBERLAND, WESTMORELAND,
EXETER, and the rest_

**KING HENRY VI**  
My lords, look where the sturdy rebel sits,  
Even in the chair of state: belike he means,  
Back'd by the power of Warwick, that false peer,  
To aspire unto the crown and reign as king.  
Earl of Northumberland, he slew thy father.  
And thine, Lord Clifford; and you both have vow'd revenge  
On him, his sons, his favourites and his friends.  

**NORTHUMBERLAND**  
If I be not, heavens be revenged on me!  

**CLIFFORD**  
The hope thereof makes Clifford mourn in steel.  

**WESTMORELAND**  
What, shall we suffer this? let's pluck him down:  
My heart for anger burns; I cannot brook it.  

**KING HENRY VI**  
Be patient, gentle Earl of Westmoreland.  

**CLIFFORD**  
Patience is for poltroons, such as he:  
He durst not sit there, had your father lived.  
My gracious lord, here in the parliament  
Let us assail the family of York.  

**NORTHUMBERLAND**  
Well hast thou spoken, cousin: be it so.  

**KING HENRY VI**  
Ah, know you not the city favours them,  
And they have troops of soldiers at their beck?  

**EXETER**  
But when the duke is slain, they'll quickly fly.  

**KING HENRY VI**  
Far be the thought of this from Henry's heart,  
To make a shambles of the parliament-house!  
Cousin of Exeter, frowns, words and threats  
Shall be the war that Henry means to use.  
Thou factious Duke of York, descend my throne,  
and kneel for grace and mercy at my feet;  
I am thy sovereign.  

**YORK**  
I am thine.  

**EXETER**  
For shame, come down: he made thee Duke of York.  

**YORK**  
'Twas my inheritance, as the earldom was.  

**EXETER**  
Thy father was a traitor to the crown.  

**WARWICK**  
Exeter, thou art a traitor to the crown  
In following this usurping Henry.  

**CLIFFORD**  
Whom should he follow but his natural king?  

**WARWICK**  
True, Clifford; and that's Richard Duke of York.  

**KING HENRY VI**  
And shall I stand, and thou sit in my throne?  

**YORK**  
It must and shall be so: content thyself.  

**WARWICK**  
Be Duke of Lancaster; let him be king.  

**WESTMORELAND**  
He is both king and Duke of Lancaster;  
And that the Lord of Westmoreland shall maintain.  

**WARWICK**  
And Warwick shall disprove it. You forget  
That we are those which chased you from the field  
And slew your fathers, and with colours spread  
March'd through the city to the palace gates.  

**NORTHUMBERLAND**  
Yes, Warwick, I remember it to my grief;  
And, by his soul, thou and thy house shall rue it.  

**WESTMORELAND**  
Plantagenet, of thee and these thy sons,  
Thy kinsman and thy friends, I'll have more lives  
Than drops of blood were in my father's veins.  

**CLIFFORD**  
Urge it no more; lest that, instead of words,  
I send thee, Warwick, such a messenger  
As shall revenge his death before I stir.  

**WARWICK**  
Poor Clifford! how I scorn his worthless threats!  

**YORK**  
Will you we show our title to the crown?  
If not, our swords shall plead it in the field.  

**KING HENRY VI**  
What title hast thou, traitor, to the crown?  
Thy father was, as thou art, Duke of York;  
Thy grandfather, Roger Mortimer, Earl of March:  
I am the son of Henry the Fifth,  
Who made the Dauphin and the French to stoop  
And seized upon their towns and provinces.  

**WARWICK**  
Talk not of France, sith thou hast lost it all.  

**KING HENRY VI**  
The lord protector lost it, and not I:  
When I was crown'd I was but nine months old.  

**RICHARD**  
You are old enough now, and yet, methinks, you lose.  
Father, tear the crown from the usurper's head.  

**EDWARD**  
Sweet father, do so; set it on your head.  

**MONTAGUE**  
Good brother, as thou lovest and honourest arms,  
Let's fight it out and not stand cavilling thus.  

**RICHARD**  
Sound drums and trumpets, and the king will fly.  

**YORK**  
Sons, peace!  

**KING HENRY VI**  
Peace, thou! and give King Henry leave to speak.  

**WARWICK**  
Plantagenet shall speak first: hear him, lords;  
And be you silent and attentive too,  
For he that interrupts him shall not live.  

**KING HENRY VI**  
Think'st thou that I will leave my kingly throne,  
Wherein my grandsire and my father sat?  
No: first shall war unpeople this my realm;  
Ay, and their colours, often borne in France,  
And now in England to our heart's great sorrow,  
Shall be my winding-sheet. Why faint you, lords?  
My title's good, and better far than his.  

**WARWICK**  
Prove it, Henry, and thou shalt be king.  

**KING HENRY VI**  
Henry the Fourth by conquest got the crown.  

**YORK**  
'Twas by rebellion against his king.  

**KING HENRY VI**  
_[Aside]_  
I know not what to say; my title's weak.--  
Tell me, may not a king adopt an heir?  

**YORK**  
What then?  

**KING HENRY VI**  
An if he may, then am I lawful king;  
For Richard, in the view of many lords,  
Resign'd the crown to Henry the Fourth,  
Whose heir my father was, and I am his.  

**YORK**  
He rose against him, being his sovereign,  
And made him to resign his crown perforce.  

**WARWICK**  
Suppose, my lords, he did it unconstrain'd,  
Think you 'twere prejudicial to his crown?  

**EXETER**  
No; for he could not so resign his crown  
But that the next heir should succeed and reign.  

**KING HENRY VI**  
Art thou against us, Duke of Exeter?  

**EXETER**  
His is the right, and therefore pardon me.  

**YORK**  
Why whisper you, my lords, and answer not?  

**EXETER**  
My conscience tells me he is lawful king.  

**KING HENRY VI**  
_[Aside]_  
All will revolt from me, and turn to him.  

**NORTHUMBERLAND**  
Plantagenet, for all the claim thou lay'st,  
Think not that Henry shall be so deposed.  

**WARWICK**  
Deposed he shall be, in despite of all.  

**NORTHUMBERLAND**  
Thou art deceived: 'tis not thy southern power,  
Of Essex, Norfolk, Suffolk, nor of Kent,  
Which makes thee thus presumptuous and proud,  
Can set the duke up in despite of me.  

**CLIFFORD**  
King Henry, be thy title right or wrong,  
Lord Clifford vows to fight in thy defence:  
May that ground gape and swallow me alive,  
Where I shall kneel to him that slew my father!  

**KING HENRY VI**  
O Clifford, how thy words revive my heart!  

**YORK**  
Henry of Lancaster, resign thy crown.  
What mutter you, or what conspire you, lords?  

**WARWICK**  
Do right unto this princely Duke of York,  
Or I will fill the house with armed men,  
And over the chair of state, where now he sits,  
Write up his title with usurping blood.  

_He stamps with his foot and the soldiers show themselves_

**KING HENRY VI**  
My Lord of Warwick, hear me but one word:  
Let me for this my life-time reign as king.  

**YORK**  
Confirm the crown to me and to mine heirs,  
And thou shalt reign in quiet while thou livest.  

**KING HENRY VI**  
I am content: Richard Plantagenet,  
Enjoy the kingdom after my decease.  

**CLIFFORD**  
What wrong is this unto the prince your son!  

**WARWICK**  
What good is this to England and himself!  

**WESTMORELAND**  
Base, fearful and despairing Henry!  

**CLIFFORD**  
How hast thou injured both thyself and us!  

**WESTMORELAND**  
I cannot stay to hear these articles.  

**NORTHUMBERLAND**  
Nor I.  

**CLIFFORD**  
Come, cousin, let us tell the queen these news.  

**WESTMORELAND**  
Farewell, faint-hearted and degenerate king,  
In whose cold blood no spark of honour bides.  

**NORTHUMBERLAND**  
Be thou a prey unto the house of York,  
And die in bands for this unmanly deed!  

**CLIFFORD**  
In dreadful war mayst thou be overcome,  
Or live in peace abandon'd and despised!  

_Exeunt NORTHUMBERLAND, CLIFFORD, and WESTMORELAND_

**WARWICK**  
Turn this way, Henry, and regard them not.  

**EXETER**  
They seek revenge and therefore will not yield.  

**KING HENRY VI**  
Ah, Exeter!  

**WARWICK**  
Why should you sigh, my lord?  

**KING HENRY VI**  
Not for myself, Lord Warwick, but my son,  
Whom I unnaturally shall disinherit.  
But be it as it may: I here entail  
The crown to thee and to thine heirs for ever;  
Conditionally, that here thou take an oath  
To cease this civil war, and, whilst I live,  
To honour me as thy king and sovereign,  
And neither by treason nor hostility  
To seek to put me down and reign thyself.  

**YORK**  
This oath I willingly take and will perform.  

**WARWICK**  
Long live King Henry! Plantagenet embrace him.  

**KING HENRY VI**  
And long live thou and these thy forward sons!  

**YORK**  
Now York and Lancaster are reconciled.  

**EXETER**  
Accursed be he that seeks to make them foes!  

_Sennet. Here they come down_

**YORK**  
Farewell, my gracious lord; I'll to my castle.  

**WARWICK**  
And I'll keep London with my soldiers.  

**NORFOLK**  
And I to Norfolk with my followers.  

**MONTAGUE**  
And I unto the sea from whence I came.  

_Exeunt YORK, EDWARD, EDMUND, GEORGE, RICHARD, WARWICK, NORFOLK, MONTAGUE,
their Soldiers, and Attendants_

**KING HENRY VI**  
And I, with grief and sorrow, to the court.  

_Enter QUEEN MARGARET and PRINCE EDWARD_

**EXETER**  
Here comes the queen, whose looks bewray her anger:  
I'll steal away.  

**KING HENRY VI**  
Exeter, so will I.  

**QUEEN MARGARET**  
Nay, go not from me; I will follow thee.  

**KING HENRY VI**  
Be patient, gentle queen, and I will stay.  

**QUEEN MARGARET**  
Who can be patient in such extremes?  
Ah, wretched man! would I had died a maid  
And never seen thee, never borne thee son,  
Seeing thou hast proved so unnatural a father  
Hath he deserved to lose his birthright thus?  
Hadst thou but loved him half so well as I,  
Or felt that pain which I did for him once,  
Or nourish'd him as I did with my blood,  
Thou wouldst have left thy dearest heart-blood there,  
Rather than have that savage duke thine heir  
And disinherited thine only son.  

**PRINCE EDWARD**  
Father, you cannot disinherit me:  
If you be king, why should not I succeed?  

**KING HENRY VI**  
Pardon me, Margaret; pardon me, sweet son:  
The Earl of Warwick and the duke enforced me.  

**QUEEN MARGARET**  
Enforced thee! art thou king, and wilt be forced?  
I shame to hear thee speak. Ah, timorous wretch!  
Thou hast undone thyself, thy son and me;  
And given unto the house of York such head  
As thou shalt reign but by their sufferance.  
To entail him and his heirs unto the crown,  
What is it, but to make thy sepulchre  
And creep into it far before thy time?  
Warwick is chancellor and the lord of Calais;  
Stern Falconbridge commands the narrow seas;  
The duke is made protector of the realm;  
And yet shalt thou be safe? such safety finds  
The trembling lamb environed with wolves.  
Had I been there, which am a silly woman,  
The soldiers should have toss'd me on their pikes  
Before I would have granted to that act.  
But thou preferr'st thy life before thine honour:  
And seeing thou dost, I here divorce myself  
Both from thy table, Henry, and thy bed,  
Until that act of parliament be repeal'd  
Whereby my son is disinherited.  
The northern lords that have forsworn thy colours  
Will follow mine, if once they see them spread;  
And spread they shall be, to thy foul disgrace  
And utter ruin of the house of York.  
Thus do I leave thee. Come, son, let's away;  
Our army is ready; come, we'll after them.  

**KING HENRY VI**  
Stay, gentle Margaret, and hear me speak.  

**QUEEN MARGARET**  
Thou hast spoke too much already: get thee gone.  

**KING HENRY VI**  
Gentle son Edward, thou wilt stay with me?  

**QUEEN MARGARET**  
Ay, to be murder'd by his enemies.  

**PRINCE EDWARD**  
When I return with victory from the field  
I'll see your grace: till then I'll follow her.  

**QUEEN MARGARET**  
Come, son, away; we may not linger thus.  

_Exeunt QUEEN MARGARET and PRINCE EDWARD_

**KING HENRY VI**  
Poor queen! how love to me and to her son  
Hath made her break out into terms of rage!  
Revenged may she be on that hateful duke,  
Whose haughty spirit, winged with desire,  
Will cost my crown, and like an empty eagle  
Tire on the flesh of me and of my son!  
The loss of those three lords torments my heart:  
I'll write unto them and entreat them fair.  
Come, cousin you shall be the messenger.  

**EXETER**  
And I, I hope, shall reconcile them all.  

_Exeunt_

### SCENE II. Sandal Castle.

_Enter RICHARD, EDWARD, and MONTAGUE_

**RICHARD**  
Brother, though I be youngest, give me leave.  

**EDWARD**  
No, I can better play the orator.  

**MONTAGUE**  
But I have reasons strong and forcible.  

_Enter YORK_

**YORK**  
Why, how now, sons and brother! at a strife?  
What is your quarrel? how began it first?  

**EDWARD**  
No quarrel, but a slight contention.  

**YORK**  
About what?  

**RICHARD**  
About that which concerns your grace and us;  
The crown of England, father, which is yours.  

**YORK**  
Mine boy? not till King Henry be dead.  

**RICHARD**  
Your right depends not on his life or death.  

**EDWARD**  
Now you are heir, therefore enjoy it now:  
By giving the house of Lancaster leave to breathe,  
It will outrun you, father, in the end.  

**YORK**  
I took an oath that he should quietly reign.  

**EDWARD**  
But for a kingdom any oath may be broken:  
I would break a thousand oaths to reign one year.  

**RICHARD**  
No; God forbid your grace should be forsworn.  

**YORK**  
I shall be, if I claim by open war.  

**RICHARD**  
I'll prove the contrary, if you'll hear me speak.  

**YORK**  
Thou canst not, son; it is impossible.  

**RICHARD**  
An oath is of no moment, being not took  
Before a true and lawful magistrate,  
That hath authority over him that swears:  
Henry had none, but did usurp the place;  
Then, seeing 'twas he that made you to depose,  
Your oath, my lord, is vain and frivolous.  
Therefore, to arms! And, father, do but think  
How sweet a thing it is to wear a crown;  
Within whose circuit is Elysium  
And all that poets feign of bliss and joy.  
Why do we finger thus? I cannot rest  
Until the white rose that I wear be dyed  
Even in the lukewarm blood of Henry's heart.  

**YORK**  
Richard, enough; I will be king, or die.  
Brother, thou shalt to London presently,  
And whet on Warwick to this enterprise.  
Thou, Richard, shalt to the Duke of Norfolk,  
And tell him privily of our intent.  
You Edward, shall unto my Lord Cobham,  
With whom the Kentishmen will willingly rise:  
In them I trust; for they are soldiers,  
Witty, courteous, liberal, full of spirit.  
While you are thus employ'd, what resteth more,  
But that I seek occasion how to rise,  
And yet the king not privy to my drift,  
Nor any of the house of Lancaster?  

_Enter a Messenger_

But, stay: what news? Why comest thou in such post?  

**Messenger**  
The queen with all the northern earls and lords  
Intend here to besiege you in your castle:  
She is hard by with twenty thousand men;  
And therefore fortify your hold, my lord.  

**YORK**  
Ay, with my sword. What! think'st thou that we fear them?  
Edward and Richard, you shall stay with me;  
My brother Montague shall post to London:  
Let noble Warwick, Cobham, and the rest,  
Whom we have left protectors of the king,  
With powerful policy strengthen themselves,  
And trust not simple Henry nor his oaths.  

**MONTAGUE**  
Brother, I go; I'll win them, fear it not:  
And thus most humbly I do take my leave.  

_Exit_

_Enter JOHN MORTIMER and HUGH MORTIMER_

Sir John and Sir Hugh Mortimer, mine uncles,  
You are come to Sandal in a happy hour;  
The army of the queen mean to besiege us.  

**JOHN MORTIMER**  
She shall not need; we'll meet her in the field.  

**YORK**  
What, with five thousand men?  

**RICHARD**  
Ay, with five hundred, father, for a need:  
A woman's general; what should we fear?  

_A march afar off_

**EDWARD**  
I hear their drums: let's set our men in order,  
And issue forth and bid them battle straight.  

**YORK**  
Five men to twenty! though the odds be great,  
I doubt not, uncle, of our victory.  
Many a battle have I won in France,  
When as the enemy hath been ten to one:  
Why should I not now have the like success?  

_Alarum. Exeunt_

### SCENE III. Field of battle betwixt Sandal Castle and Wakefield.

_Alarums. Enter RUTLAND and his Tutor_

**RUTLAND**  
Ah, whither shall I fly to 'scape their hands?  
Ah, tutor, look where bloody Clifford comes!  

_Enter CLIFFORD and Soldiers_

**CLIFFORD**  
Chaplain, away! thy priesthood saves thy life.  
As for the brat of this accursed duke,  
Whose father slew my father, he shall die.  

**Tutor**  
And I, my lord, will bear him company.  

**CLIFFORD**  
Soldiers, away with him!  

**Tutor**  
Ah, Clifford, murder not this innocent child,  
Lest thou be hated both of God and man!  

_Exit, dragged off by Soldiers_

**CLIFFORD**  
How now! is he dead already? or is it fear  
That makes him close his eyes? I'll open them.  

**RUTLAND**  
So looks the pent-up lion o'er the wretch  
That trembles under his devouring paws;  
And so he walks, insulting o'er his prey,  
And so he comes, to rend his limbs asunder.  
Ah, gentle Clifford, kill me with thy sword,  
And not with such a cruel threatening look.  
Sweet Clifford, hear me speak before I die.  
I am too mean a subject for thy wrath:  
Be thou revenged on men, and let me live.  

**CLIFFORD**  
In vain thou speak'st, poor boy; my father's blood  
Hath stopp'd the passage where thy words should enter.  

**RUTLAND**  
Then let my father's blood open it again:  
He is a man, and, Clifford, cope with him.  

**CLIFFORD**  
Had thy brethren here, their lives and thine  
Were not revenge sufficient for me;  
No, if I digg'd up thy forefathers' graves  
And hung their rotten coffins up in chains,  
It could not slake mine ire, nor ease my heart.  
The sight of any of the house of York  
Is as a fury to torment my soul;  
And till I root out their accursed line  
And leave not one alive, I live in hell.  
Therefore--  

_Lifting his hand_

**RUTLAND**  
O, let me pray before I take my death!  
To thee I pray; sweet Clifford, pity me!  

**CLIFFORD**  
Such pity as my rapier's point affords.  

**RUTLAND**  
I never did thee harm: why wilt thou slay me?  

**CLIFFORD**  
Thy father hath.  

**RUTLAND**  
But 'twas ere I was born.  
Thou hast one son; for his sake pity me,  
Lest in revenge thereof, sith God is just,  
He be as miserably slain as I.  
Ah, let me live in prison all my days;  
And when I give occasion of offence,  
Then let me die, for now thou hast no cause.  

**CLIFFORD**  
No cause!  
Thy father slew my father; therefore, die.  

_Stabs him_

**RUTLAND**  
Di faciant laudis summa sit ista tuae!  

_Dies_

**CLIFFORD**  
Plantagenet! I come, Plantagenet!  
And this thy son's blood cleaving to my blade  
Shall rust upon my weapon, till thy blood,  
Congeal'd with this, do make me wipe off both.  

_Exit_

### SCENE IV. Another part of the field.

_Alarum. Enter YORK_

**YORK**  
The army of the queen hath got the field:  
My uncles both are slain in rescuing me;  
And all my followers to the eager foe  
Turn back and fly, like ships before the wind  
Or lambs pursued by hunger-starved wolves.  
My sons, God knows what hath bechanced them:  
But this I know, they have demean'd themselves  
Like men born to renown by life or death.  
Three times did Richard make a lane to me.  
And thrice cried 'Courage, father! fight it out!'  
And full as oft came Edward to my side,  
With purple falchion, painted to the hilt  
In blood of those that had encounter'd him:  
And when the hardiest warriors did retire,  
Richard cried 'Charge! and give no foot of ground!'  
And cried 'A crown, or else a glorious tomb!  
A sceptre, or an earthly sepulchre!'  
With this, we charged again: but, out, alas!  
We bodged again; as I have seen a swan  
With bootless labour swim against the tide  
And spend her strength with over-matching waves.  

_A short alarum within_

Ah, hark! the fatal followers do pursue;  
And I am faint and cannot fly their fury:  
And were I strong, I would not shun their fury:  
The sands are number'd that make up my life;  
Here must I stay, and here my life must end.  

_Enter QUEEN MARGARET, CLIFFORD, NORTHUMBERLAND, PRINCE EDWARD, and
Soldiers_

Come, bloody Clifford, rough Northumberland,  
I dare your quenchless fury to more rage:  
I am your butt, and I abide your shot.  

**NORTHUMBERLAND**  
Yield to our mercy, proud Plantagenet.  

**CLIFFORD**  
Ay, to such mercy as his ruthless arm,  
With downright payment, show'd unto my father.  
Now Phaethon hath tumbled from his car,  
And made an evening at the noontide prick.  

**YORK**  
My ashes, as the phoenix, may bring forth  
A bird that will revenge upon you all:  
And in that hope I throw mine eyes to heaven,  
Scorning whate'er you can afflict me with.  
Why come you not? what! multitudes, and fear?  

**CLIFFORD**  
So cowards fight when they can fly no further;  
So doves do peck the falcon's piercing talons;  
So desperate thieves, all hopeless of their lives,  
Breathe out invectives 'gainst the officers.  

**YORK**  
O Clifford, but bethink thee once again,  
And in thy thought o'er-run my former time;  
And, if though canst for blushing, view this face,  
And bite thy tongue, that slanders him with cowardice  
Whose frown hath made thee faint and fly ere this!  

**CLIFFORD**  
I will not bandy with thee word for word,  
But buckle with thee blows, twice two for one.  

**QUEEN MARGARET**  
Hold, valiant Clifford! for a thousand causes  
I would prolong awhile the traitor's life.  
Wrath makes him deaf: speak thou, Northumberland.  

**NORTHUMBERLAND**  
Hold, Clifford! do not honour him so much  
To prick thy finger, though to wound his heart:  
What valour were it, when a cur doth grin,  
For one to thrust his hand between his teeth,  
When he might spurn him with his foot away?  
It is war's prize to take all vantages;  
And ten to one is no impeach of valour.  

_They lay hands on YORK, who struggles_

**CLIFFORD**  
Ay, ay, so strives the woodcock with the gin.  

**NORTHUMBERLAND**  
So doth the cony struggle in the net.  

**YORK**  
So triumph thieves upon their conquer'd booty;  
So true men yield, with robbers so o'ermatch'd.  

**NORTHUMBERLAND**  
What would your grace have done unto him now?  

**QUEEN MARGARET**  
Brave warriors, Clifford and Northumberland,  
Come, make him stand upon this molehill here,  
That raught at mountains with outstretched arms,  
Yet parted but the shadow with his hand.  
What! was it you that would be England's king?  
Was't you that revell'd in our parliament,  
And made a preachment of your high descent?  
Where are your mess of sons to back you now?  
The wanton Edward, and the lusty George?  
And where's that valiant crook-back prodigy,  
Dicky your boy, that with his grumbling voice  
Was wont to cheer his dad in mutinies?  
Or, with the rest, where is your darling Rutland?  
Look, York: I stain'd this napkin with the blood  
That valiant Clifford, with his rapier's point,  
Made issue from the bosom of the boy;  
And if thine eyes can water for his death,  
I give thee this to dry thy cheeks withal.  
Alas poor York! but that I hate thee deadly,  
I should lament thy miserable state.  
I prithee, grieve, to make me merry, York.  
What, hath thy fiery heart so parch'd thine entrails  
That not a tear can fall for Rutland's death?  
Why art thou patient, man? thou shouldst be mad;  
And I, to make thee mad, do mock thee thus.  
Stamp, rave, and fret, that I may sing and dance.  
Thou wouldst be fee'd, I see, to make me sport:  
York cannot speak, unless he wear a crown.  
A crown for York! and, lords, bow low to him:  
Hold you his hands, whilst I do set it on.  

_Putting a paper crown on his head_

Ay, marry, sir, now looks he like a king!  
Ay, this is he that took King Henry's chair,  
And this is he was his adopted heir.  
But how is it that great Plantagenet  
Is crown'd so soon, and broke his solemn oath?  
As I bethink me, you should not be king  
Till our King Henry had shook hands with death.  
And will you pale your head in Henry's glory,  
And rob his temples of the diadem,  
Now in his life, against your holy oath?  
O, 'tis a fault too too unpardonable!  
Off with the crown, and with the crown his head;  
And, whilst we breathe, take time to do him dead.  

**CLIFFORD**  
That is my office, for my father's sake.  

**QUEEN MARGARET**  
Nay, stay; lets hear the orisons he makes.  

**YORK**  
She-wolf of France, but worse than wolves of France,  
Whose tongue more poisons than the adder's tooth!  
How ill-beseeming is it in thy sex  
To triumph, like an Amazonian trull,  
Upon their woes whom fortune captivates!  
But that thy face is, vizard-like, unchanging,  
Made impudent with use of evil deeds,  
I would assay, proud queen, to make thee blush.  
To tell thee whence thou camest, of whom derived,  
Were shame enough to shame thee, wert thou not shameless.  
Thy father bears the type of King of Naples,  
Of both the Sicils and Jerusalem,  
Yet not so wealthy as an English yeoman.  
Hath that poor monarch taught thee to insult?  
It needs not, nor it boots thee not, proud queen,  
Unless the adage must be verified,  
That beggars mounted run their horse to death.  
'Tis beauty that doth oft make women proud;  
But, God he knows, thy share thereof is small:  
'Tis virtue that doth make them most admired;  
The contrary doth make thee wonder'd at:  
'Tis government that makes them seem divine;  
The want thereof makes thee abominable:  
Thou art as opposite to every good  
As the Antipodes are unto us,  
Or as the south to the septentrion.  
O tiger's heart wrapt in a woman's hide!  
How couldst thou drain the life-blood of the child,  
To bid the father wipe his eyes withal,  
And yet be seen to bear a woman's face?  
Women are soft, mild, pitiful and flexible;  
Thou stern, obdurate, flinty, rough, remorseless.  
Bids't thou me rage? why, now thou hast thy wish:  
Wouldst have me weep? why, now thou hast thy will:  
For raging wind blows up incessant showers,  
And when the rage allays, the rain begins.  
These tears are my sweet Rutland's obsequies:  
And every drop cries vengeance for his death,  
'Gainst thee, fell Clifford, and thee, false  
Frenchwoman.  

**NORTHUMBERLAND**  
Beshrew me, but his passion moves me so  
That hardly can I cheque my eyes from tears.  

**YORK**  
That face of his the hungry cannibals  
Would not have touch'd, would not have stain'd with blood:  
But you are more inhuman, more inexorable,  
O, ten times more, than tigers of Hyrcania.  
See, ruthless queen, a hapless father's tears:  
This cloth thou dip'dst in blood of my sweet boy,  
And I with tears do wash the blood away.  
Keep thou the napkin, and go boast of this:  
And if thou tell'st the heavy story right,  
Upon my soul, the hearers will shed tears;  
Yea even my foes will shed fast-falling tears,  
And say 'Alas, it was a piteous deed!'  
There, take the crown, and, with the crown, my curse;  
And in thy need such comfort come to thee  
As now I reap at thy too cruel hand!  
Hard-hearted Clifford, take me from the world:  
My soul to heaven, my blood upon your heads!  

**NORTHUMBERLAND**  
Had he been slaughter-man to all my kin,  
I should not for my life but weep with him.  
To see how inly sorrow gripes his soul.  

**QUEEN MARGARET**  
What, weeping-ripe, my Lord Northumberland?  
Think but upon the wrong he did us all,  
And that will quickly dry thy melting tears.  

**CLIFFORD**  
Here's for my oath, here's for my father's death.  

_Stabbing him_

**QUEEN MARGARET**  
And here's to right our gentle-hearted king.  

_Stabbing him_

**YORK**  
Open Thy gate of mercy, gracious God!  
My soul flies through these wounds to seek out Thee.  

_Dies_

**QUEEN MARGARET**  
Off with his head, and set it on York gates;  
So York may overlook the town of York.  

_Flourish. Exeunt_

# ACT II

### SCENE I. A plain near Mortimer's Cross in Herefordshire.

_A march. Enter EDWARD, RICHARD, and their power_

**EDWARD**  
I wonder how our princely father 'scaped,  
Or whether he be 'scaped away or no  
From Clifford's and Northumberland's pursuit:  
Had he been ta'en, we should have heard the news;  
Had he been slain, we should have heard the news;  
Or had he 'scaped, methinks we should have heard  
The happy tidings of his good escape.  
How fares my brother? why is he so sad?  

**RICHARD**  
I cannot joy, until I be resolved  
Where our right valiant father is become.  
I saw him in the battle range about;  
And watch'd him how he singled Clifford forth.  
Methought he bore him in the thickest troop  
As doth a lion in a herd of neat;  
Or as a bear, encompass'd round with dogs,  
Who having pinch'd a few and made them cry,  
The rest stand all aloof, and bark at him.  
So fared our father with his enemies;  
So fled his enemies my warlike father:  
Methinks, 'tis prize enough to be his son.  
See how the morning opes her golden gates,  
And takes her farewell of the glorious sun!  
How well resembles it the prime of youth,  
Trimm'd like a younker prancing to his love!  

**EDWARD**  
Dazzle mine eyes, or do I see three suns?  

**RICHARD**  
Three glorious suns, each one a perfect sun;  
Not separated with the racking clouds,  
But sever'd in a pale clear-shining sky.  
See, see! they join, embrace, and seem to kiss,  
As if they vow'd some league inviolable:  
Now are they but one lamp, one light, one sun.  
In this the heaven figures some event.  

**EDWARD**  
'Tis wondrous strange, the like yet never heard of.  
I think it cites us, brother, to the field,  
That we, the sons of brave Plantagenet,  
Each one already blazing by our meeds,  
Should notwithstanding join our lights together  
And over-shine the earth as this the world.  
Whate'er it bodes, henceforward will I bear  
Upon my target three fair-shining suns.  

**RICHARD**  
Nay, bear three daughters: by your leave I speak it,  
You love the breeder better than the male.  

_Enter a Messenger_

But what art thou, whose heavy looks foretell  
Some dreadful story hanging on thy tongue?  

**Messenger**  
Ah, one that was a woful looker-on  
When as the noble Duke of York was slain,  
Your princely father and my loving lord!  

**EDWARD**  
O, speak no more, for I have heard too much.  

**RICHARD**  
Say how he died, for I will hear it all.  

**Messenger**  
Environed he was with many foes,  
And stood against them, as the hope of Troy  
Against the Greeks that would have enter'd Troy.  
But Hercules himself must yield to odds;  
And many strokes, though with a little axe,  
Hew down and fell the hardest-timber'd oak.  
By many hands your father was subdued;  
But only slaughter'd by the ireful arm  
Of unrelenting Clifford and the queen,  
Who crown'd the gracious duke in high despite,  
Laugh'd in his face; and when with grief he wept,  
The ruthless queen gave him to dry his cheeks  
A napkin steeped in the harmless blood  
Of sweet young Rutland, by rough Clifford slain:  
And after many scorns, many foul taunts,  
They took his head, and on the gates of York  
They set the same; and there it doth remain,  
The saddest spectacle that e'er I view'd.  

**EDWARD**  
Sweet Duke of York, our prop to lean upon,  
Now thou art gone, we have no staff, no stay.  
O Clifford, boisterous Clifford! thou hast slain  
The flower of Europe for his chivalry;  
And treacherously hast thou vanquish'd him,  
For hand to hand he would have vanquish'd thee.  
Now my soul's palace is become a prison:  
Ah, would she break from hence, that this my body  
Might in the ground be closed up in rest!  
For never henceforth shall I joy again,  
Never, O never shall I see more joy!  

**RICHARD**  
I cannot weep; for all my body's moisture  
Scarce serves to quench my furnace-burning heart:  
Nor can my tongue unload my heart's great burthen;  
For selfsame wind that I should speak withal  
Is kindling coals that fires all my breast,  
And burns me up with flames that tears would quench.  
To weep is to make less the depth of grief:  
Tears then for babes; blows and revenge for me  
Richard, I bear thy name; I'll venge thy death,  
Or die renowned by attempting it.  

**EDWARD**  
His name that valiant duke hath left with thee;  
His dukedom and his chair with me is left.  

**RICHARD**  
Nay, if thou be that princely eagle's bird,  
Show thy descent by gazing 'gainst the sun:  
For chair and dukedom, throne and kingdom say;  
Either that is thine, or else thou wert not his.  

_March. Enter WARWICK, MONTAGUE, and their army_

**WARWICK**  
How now, fair lords! What fare? what news abroad?  

**RICHARD**  
Great Lord of Warwick, if we should recount  
Our baleful news, and at each word's deliverance  
Stab poniards in our flesh till all were told,  
The words would add more anguish than the wounds.  
O valiant lord, the Duke of York is slain!  

**EDWARD**  
O Warwick, Warwick! that Plantagenet,  
Which held three dearly as his soul's redemption,  
Is by the stern Lord Clifford done to death.  

**WARWICK**  
Ten days ago I drown'd these news in tears;  
And now, to add more measure to your woes,  
I come to tell you things sith then befall'n.  
After the bloody fray at Wakefield fought,  
Where your brave father breathed his latest gasp,  
Tidings, as swiftly as the posts could run,  
Were brought me of your loss and his depart.  
I, then in London keeper of the king,  
Muster'd my soldiers, gather'd flocks of friends,  
And very well appointed, as I thought,  
March'd toward Saint Alban's to intercept the queen,  
Bearing the king in my behalf along;  
For by my scouts I was advertised  
That she was coming with a full intent  
To dash our late decree in parliament  
Touching King Henry's oath and your succession.  
Short tale to make, we at Saint Alban's met  
Our battles join'd, and both sides fiercely fought:  
But whether 'twas the coldness of the king,  
Who look'd full gently on his warlike queen,  
That robb'd my soldiers of their heated spleen;  
Or whether 'twas report of her success;  
Or more than common fear of Clifford's rigour,  
Who thunders to his captives blood and death,  
I cannot judge: but to conclude with truth,  
Their weapons like to lightning came and went;  
Our soldiers', like the night-owl's lazy flight,  
Or like an idle thresher with a flail,  
Fell gently down, as if they struck their friends.  
I cheer'd them up with justice of our cause,  
With promise of high pay and great rewards:  
But all in vain; they had no heart to fight,  
And we in them no hope to win the day;  
So that we fled; the king unto the queen;  
Lord George your brother, Norfolk and myself,  
In haste, post-haste, are come to join with you:  
For in the marches here we heard you were,  
Making another head to fight again.  

**EDWARD**  
Where is the Duke of Norfolk, gentle Warwick?  
And when came George from Burgundy to England?  

**WARWICK**  
Some six miles off the duke is with the soldiers;  
And for your brother, he was lately sent  
From your kind aunt, Duchess of Burgundy,  
With aid of soldiers to this needful war.  

**RICHARD**  
'Twas odds, belike, when valiant Warwick fled:  
Oft have I heard his praises in pursuit,  
But ne'er till now his scandal of retire.  

**WARWICK**  
Nor now my scandal, Richard, dost thou hear;  
For thou shalt know this strong right hand of mine  
Can pluck the diadem from faint Henry's head,  
And wring the awful sceptre from his fist,  
Were he as famous and as bold in war  
As he is famed for mildness, peace, and prayer.  

**RICHARD**  
I know it well, Lord Warwick; blame me not:  
'Tis love I bear thy glories makes me speak.  
But in this troublous time what's to be done?  
Shall we go throw away our coats of steel,  
And wrap our bodies in black mourning gowns,  
Numbering our Ave-Maries with our beads?  
Or shall we on the helmets of our foes  
Tell our devotion with revengeful arms?  
If for the last, say ay, and to it, lords.  

**WARWICK**  
Why, therefore Warwick came to seek you out;  
And therefore comes my brother Montague.  
Attend me, lords. The proud insulting queen,  
With Clifford and the haught Northumberland,  
And of their feather many more proud birds,  
Have wrought the easy-melting king like wax.  
He swore consent to your succession,  
His oath enrolled in the parliament;  
And now to London all the crew are gone,  
To frustrate both his oath and what beside  
May make against the house of Lancaster.  
Their power, I think, is thirty thousand strong:  
Now, if the help of Norfolk and myself,  
With all the friends that thou, brave Earl of March,  
Amongst the loving Welshmen canst procure,  
Will but amount to five and twenty thousand,  
Why, Via! to London will we march amain,  
And once again bestride our foaming steeds,  
And once again cry 'Charge upon our foes!'  
But never once again turn back and fly.  

**RICHARD**  
Ay, now methinks I hear great Warwick speak:  
Ne'er may he live to see a sunshine day,  
That cries 'Retire,' if Warwick bid him stay.  

**EDWARD**  
Lord Warwick, on thy shoulder will I lean;  
And when thou fail'st--as God forbid the hour!--  
Must Edward fall, which peril heaven forfend!  

**WARWICK**  
No longer Earl of March, but Duke of York:  
The next degree is England's royal throne;  
For King of England shalt thou be proclaim'd  
In every borough as we pass along;  
And he that throws not up his cap for joy  
Shall for the fault make forfeit of his head.  
King Edward, valiant Richard, Montague,  
Stay we no longer, dreaming of renown,  
But sound the trumpets, and about our task.  

**RICHARD**  
Then, Clifford, were thy heart as hard as steel,  
As thou hast shown it flinty by thy deeds,  
I come to pierce it, or to give thee mine.  

**EDWARD**  
Then strike up drums: God and Saint George for us!  

_Enter a Messenger_

**WARWICK**  
How now! what news?  

**Messenger**  
The Duke of Norfolk sends you word by me,  
The queen is coming with a puissant host;  
And craves your company for speedy counsel.  

**WARWICK**  
Why then it sorts, brave warriors, let's away.  

_Exeunt_

### SCENE II. Before York.

_Flourish. Enter KING HENRY VI, QUEEN MARGARET, PRINCE EDWARD, CLIFFORD, and
NORTHUMBERLAND, with drum and trumpets_

**QUEEN MARGARET**  
Welcome, my lord, to this brave town of York.  
Yonder's the head of that arch-enemy  
That sought to be encompass'd with your crown:  
Doth not the object cheer your heart, my lord?  

**KING HENRY VI**  
Ay, as the rocks cheer them that fear their wreck:  
To see this sight, it irks my very soul.  
Withhold revenge, dear God! 'tis not my fault,  
Nor wittingly have I infringed my vow.  

**CLIFFORD**  
My gracious liege, this too much lenity  
And harmful pity must be laid aside.  
To whom do lions cast their gentle looks?  
Not to the beast that would usurp their den.  
Whose hand is that the forest bear doth lick?  
Not his that spoils her young before her face.  
Who 'scapes the lurking serpent's mortal sting?  
Not he that sets his foot upon her back.  
The smallest worm will turn being trodden on,  
And doves will peck in safeguard of their brood.  
Ambitious York doth level at thy crown,  
Thou smiling while he knit his angry brows:  
He, but a duke, would have his son a king,  
And raise his issue, like a loving sire;  
Thou, being a king, blest with a goodly son,  
Didst yield consent to disinherit him,  
Which argued thee a most unloving father.  
Unreasonable creatures feed their young;  
And though man's face be fearful to their eyes,  
Yet, in protection of their tender ones,  
Who hath not seen them, even with those wings  
Which sometime they have used with fearful flight,  
Make war with him that climb'd unto their nest,  
Offer their own lives in their young's defence?  
For shame, my liege, make them your precedent!  
Were it not pity that this goodly boy  
Should lose his birthright by his father's fault,  
And long hereafter say unto his child,  
'What my great-grandfather and his grandsire got  
My careless father fondly gave away'?  
Ah, what a shame were this! Look on the boy;  
And let his manly face, which promiseth  
Successful fortune, steel thy melting heart  
To hold thine own and leave thine own with him.  

**KING HENRY VI**  
Full well hath Clifford play'd the orator,  
Inferring arguments of mighty force.  
But, Clifford, tell me, didst thou never hear  
That things ill-got had ever bad success?  
And happy always was it for that son  
Whose father for his hoarding went to hell?  
I'll leave my son my virtuous deeds behind;  
And would my father had left me no more!  
For all the rest is held at such a rate  
As brings a thousand-fold more care to keep  
Than in possession and jot of pleasure.  
Ah, cousin York! would thy best friends did know  
How it doth grieve me that thy head is here!  

**QUEEN MARGARET**  
My lord, cheer up your spirits: our foes are nigh,  
And this soft courage makes your followers faint.  
You promised knighthood to our forward son:  
Unsheathe your sword, and dub him presently.  
Edward, kneel down.  

**KING HENRY VI**  
Edward Plantagenet, arise a knight;  
And learn this lesson, draw thy sword in right.  

**PRINCE**  
My gracious father, by your kingly leave,  
I'll draw it as apparent to the crown,  
And in that quarrel use it to the death.  

**CLIFFORD**  
Why, that is spoken like a toward prince.  

_Enter a Messenger_

**Messenger**  
Royal commanders, be in readiness:  
For with a band of thirty thousand men  
Comes Warwick, backing of the Duke of York;  
And in the towns, as they do march along,  
Proclaims him king, and many fly to him:  
Darraign your battle, for they are at hand.  

**CLIFFORD**  
I would your highness would depart the field:  
The queen hath best success when you are absent.  

**QUEEN MARGARET**  
Ay, good my lord, and leave us to our fortune.  

**KING HENRY VI**  
Why, that's my fortune too; therefore I'll stay.  

**NORTHUMBERLAND**  
Be it with resolution then to fight.  

**PRINCE EDWARD**  
My royal father, cheer these noble lords  
And hearten those that fight in your defence:  
Unsheathe your sword, good father; cry 'Saint George!'  

_March. Enter EDWARD, GEORGE, RICHARD, WARWICK, NORFOLK, MONTAGUE, and
Soldiers_

**EDWARD**  
Now, perjured Henry! wilt thou kneel for grace,  
And set thy diadem upon my head;  
Or bide the mortal fortune of the field?  

**QUEEN MARGARET**  
Go, rate thy minions, proud insulting boy!  
Becomes it thee to be thus bold in terms  
Before thy sovereign and thy lawful king?  

**EDWARD**  
I am his king, and he should bow his knee;  
I was adopted heir by his consent:  
Since when, his oath is broke; for, as I hear,  
You, that are king, though he do wear the crown,  
Have caused him, by new act of parliament,  
To blot out me, and put his own son in.  

**CLIFFORD**  
And reason too:  
Who should succeed the father but the son?  

**RICHARD**  
Are you there, butcher? O, I cannot speak!  

**CLIFFORD**  
Ay, crook-back, here I stand to answer thee,  
Or any he the proudest of thy sort.  

**RICHARD**  
'Twas you that kill'd young Rutland, was it not?  

**CLIFFORD**  
Ay, and old York, and yet not satisfied.  

**RICHARD**  
For God's sake, lords, give signal to the fight.  

**WARWICK**  
What say'st thou, Henry, wilt thou yield the crown?  

**QUEEN MARGARET**  
Why, how now, long-tongued Warwick! dare you speak?  
When you and I met at Saint Alban's last,  
Your legs did better service than your hands.  

**WARWICK**  
Then 'twas my turn to fly, and now 'tis thine.  

**CLIFFORD**  
You said so much before, and yet you fled.  

**WARWICK**  
'Twas not your valour, Clifford, drove me thence.  

**NORTHUMBERLAND**  
No, nor your manhood that durst make you stay.  

**RICHARD**  
Northumberland, I hold thee reverently.  
Break off the parley; for scarce I can refrain  
The execution of my big-swoln heart  
Upon that Clifford, that cruel child-killer.  

**CLIFFORD**  
I slew thy father, call'st thou him a child?  

**RICHARD**  
Ay, like a dastard and a treacherous coward,  
As thou didst kill our tender brother Rutland;  
But ere sunset I'll make thee curse the deed.  

**KING HENRY VI**  
Have done with words, my lords, and hear me speak.  

**QUEEN MARGARET**  
Defy them then, or else hold close thy lips.  

**KING HENRY VI**  
I prithee, give no limits to my tongue:  
I am a king, and privileged to speak.  

**CLIFFORD**  
My liege, the wound that bred this meeting here  
Cannot be cured by words; therefore be still.  

**RICHARD**  
Then, executioner, unsheathe thy sword:  
By him that made us all, I am resolved  
that Clifford's manhood lies upon his tongue.  

**EDWARD**  
Say, Henry, shall I have my right, or no?  
A thousand men have broke their fasts to-day,  
That ne'er shall dine unless thou yield the crown.  

**WARWICK**  
If thou deny, their blood upon thy head;  
For York in justice puts his armour on.  

**PRINCE EDWARD**  
If that be right which Warwick says is right,  
There is no wrong, but every thing is right.  

**RICHARD**  
Whoever got thee, there thy mother stands;  
For, well I wot, thou hast thy mother's tongue.  

**QUEEN MARGARET**  
But thou art neither like thy sire nor dam;  
But like a foul mis-shapen stigmatic,  
Mark'd by the destinies to be avoided,  
As venom toads, or lizards' dreadful stings.  

**RICHARD**  
Iron of Naples hid with English gilt,  
Whose father bears the title of a king,--  
As if a channel should be call'd the sea,--  
Shamest thou not, knowing whence thou art extraught,  
To let thy tongue detect thy base-born heart?  

**EDWARD**  
A wisp of straw were worth a thousand crowns,  
To make this shameless callet know herself.  
Helen of Greece was fairer far than thou,  
Although thy husband may be Menelaus;  
And ne'er was Agamemnon's brother wrong'd  
By that false woman, as this king by thee.  
His father revell'd in the heart of France,  
And tamed the king, and made the dauphin stoop;  
And had he match'd according to his state,  
He might have kept that glory to this day;  
But when he took a beggar to his bed,  
And graced thy poor sire with his bridal-day,  
Even then that sunshine brew'd a shower for him,  
That wash'd his father's fortunes forth of France,  
And heap'd sedition on his crown at home.  
For what hath broach'd this tumult but thy pride?  
Hadst thou been meek, our title still had slept;  
And we, in pity of the gentle king,  
Had slipp'd our claim until another age.  

**GEORGE**  
But when we saw our sunshine made thy spring,  
And that thy summer bred us no increase,  
We set the axe to thy usurping root;  
And though the edge hath something hit ourselves,  
Yet, know thou, since we have begun to strike,  
We'll never leave till we have hewn thee down,  
Or bathed thy growing with our heated bloods.  

**EDWARD**  
And, in this resolution, I defy thee;  
Not willing any longer conference,  
Since thou deniest the gentle king to speak.  
Sound trumpets! let our bloody colours wave!  
And either victory, or else a grave.  

**QUEEN MARGARET**  
Stay, Edward.  

**EDWARD**  
No, wrangling woman, we'll no longer stay:  
These words will cost ten thousand lives this day.  

_Exeunt_

### SCENE III. A field of battle between Towton and Saxton, in

Yorkshire.  

_Alarum. Excursions. Enter WARWICK_

**WARWICK**  
Forspent with toil, as runners with a race,  
I lay me down a little while to breathe;  
For strokes received, and many blows repaid,  
Have robb'd my strong-knit sinews of their strength,  
And spite of spite needs must I rest awhile.  

_Enter EDWARD, running_

**EDWARD**  
Smile, gentle heaven! or strike, ungentle death!  
For this world frowns, and Edward's sun is clouded.  

**WARWICK**  
How now, my lord! what hap? what hope of good?  

_Enter GEORGE_

**GEORGE**  
Our hap is loss, our hope but sad despair;  
Our ranks are broke, and ruin follows us:  
What counsel give you? whither shall we fly?  

**EDWARD**  
Bootless is flight, they follow us with wings;  
And weak we are and cannot shun pursuit.  

_Enter RICHARD_

**RICHARD**  
Ah, Warwick, why hast thou withdrawn thyself?  
Thy brother's blood the thirsty earth hath drunk,  
Broach'd with the steely point of Clifford's lance;  
And in the very pangs of death he cried,  
Like to a dismal clangour heard from far,  
'Warwick, revenge! brother, revenge my death!'  
So, underneath the belly of their steeds,  
That stain'd their fetlocks in his smoking blood,  
The noble gentleman gave up the ghost.  

**WARWICK**  
Then let the earth be drunken with our blood:  
I'll kill my horse, because I will not fly.  
Why stand we like soft-hearted women here,  
Wailing our losses, whiles the foe doth rage;  
And look upon, as if the tragedy  
Were play'd in jest by counterfeiting actors?  
Here on my knee I vow to God above,  
I'll never pause again, never stand still,  
Till either death hath closed these eyes of mine  
Or fortune given me measure of revenge.  

**EDWARD**  
O Warwick, I do bend my knee with thine;  
And in this vow do chain my soul to thine!  
And, ere my knee rise from the earth's cold face,  
I throw my hands, mine eyes, my heart to thee,  
Thou setter up and plucker down of kings,  
Beseeching thee, if with they will it stands  
That to my foes this body must be prey,  
Yet that thy brazen gates of heaven may ope,  
And give sweet passage to my sinful soul!  
Now, lords, take leave until we meet again,  
Where'er it be, in heaven or in earth.  

**RICHARD**  
Brother, give me thy hand; and, gentle Warwick,  
Let me embrace thee in my weary arms:  
I, that did never weep, now melt with woe  
That winter should cut off our spring-time so.  

**WARWICK**  
Away, away! Once more, sweet lords farewell.  

**GEORGE**  
Yet let us all together to our troops,  
And give them leave to fly that will not stay;  
And call them pillars that will stand to us;  
And, if we thrive, promise them such rewards  
As victors wear at the Olympian games:  
This may plant courage in their quailing breasts;  
For yet is hope of life and victory.  
Forslow no longer, make we hence amain.  

_Exeunt_

### SCENE IV. Another part of the field.

_Excursions. Enter RICHARD and CLIFFORD_

**RICHARD**  
Now, Clifford, I have singled thee alone:  
Suppose this arm is for the Duke of York,  
And this for Rutland; both bound to revenge,  
Wert thou environ'd with a brazen wall.  

**CLIFFORD**  
Now, Richard, I am with thee here alone:  
This is the hand that stabb'd thy father York;  
And this the hand that slew thy brother Rutland;  
And here's the heart that triumphs in their death  
And cheers these hands that slew thy sire and brother  
To execute the like upon thyself;  
And so, have at thee!  

_They fight. WARWICK comes; CLIFFORD flies_

**RICHARD**  
Nay Warwick, single out some other chase;  
For I myself will hunt this wolf to death.  

_Exeunt_

### SCENE V. Another part of the field.

_Alarum. Enter KING HENRY VI alone_

**KING HENRY VI**  
This battle fares like to the morning's war,  
When dying clouds contend with growing light,  
What time the shepherd, blowing of his nails,  
Can neither call it perfect day nor night.  
Now sways it this way, like a mighty sea  
Forced by the tide to combat with the wind;  
Now sways it that way, like the selfsame sea  
Forced to retire by fury of the wind:  
Sometime the flood prevails, and then the wind;  
Now one the better, then another best;  
Both tugging to be victors, breast to breast,  
Yet neither conqueror nor conquered:  
So is the equal of this fell war.  
Here on this molehill will I sit me down.  
To whom God will, there be the victory!  
For Margaret my queen, and Clifford too,  
Have chid me from the battle; swearing both  
They prosper best of all when I am thence.  
Would I were dead! if God's good will were so;  
For what is in this world but grief and woe?  
O God! methinks it were a happy life,  
To be no better than a homely swain;  
To sit upon a hill, as I do now,  
To carve out dials quaintly, point by point,  
Thereby to see the minutes how they run,  
How many make the hour full complete;  
How many hours bring about the day;  
How many days will finish up the year;  
How many years a mortal man may live.  
When this is known, then to divide the times:  
So many hours must I tend my flock;  
So many hours must I take my rest;  
So many hours must I contemplate;  
So many hours must I sport myself;  
So many days my ewes have been with young;  
So many weeks ere the poor fools will ean:  
So many years ere I shall shear the fleece:  
So minutes, hours, days, months, and years,  
Pass'd over to the end they were created,  
Would bring white hairs unto a quiet grave.  
Ah, what a life were this! how sweet! how lovely!  
Gives not the hawthorn-bush a sweeter shade  
To shepherds looking on their silly sheep,  
Than doth a rich embroider'd canopy  
To kings that fear their subjects' treachery?  
O, yes, it doth; a thousand-fold it doth.  
And to conclude, the shepherd's homely curds,  
His cold thin drink out of his leather bottle.  
His wonted sleep under a fresh tree's shade,  
All which secure and sweetly he enjoys,  
Is far beyond a prince's delicates,  
His viands sparkling in a golden cup,  
His body couched in a curious bed,  
When care, mistrust, and treason waits on him.  

_Alarum. Enter a Son that has killed his father, dragging in the dead body_

**Son**  
Ill blows the wind that profits nobody.  
This man, whom hand to hand I slew in fight,  
May be possessed with some store of crowns;  
And I, that haply take them from him now,  
May yet ere night yield both my life and them  
To some man else, as this dead man doth me.  
Who's this? O God! it is my father's face,  
Whom in this conflict I unwares have kill'd.  
O heavy times, begetting such events!  
From London by the king was I press'd forth;  
My father, being the Earl of Warwick's man,  
Came on the part of York, press'd by his master;  
And I, who at his hands received my life, him  
Have by my hands of life bereaved him.  
Pardon me, God, I knew not what I did!  
And pardon, father, for I knew not thee!  
My tears shall wipe away these bloody marks;  
And no more words till they have flow'd their fill.  

**KING HENRY VI**  
O piteous spectacle! O bloody times!  
Whiles lions war and battle for their dens,  
Poor harmless lambs abide their enmity.  
Weep, wretched man, I'll aid thee tear for tear;  
And let our hearts and eyes, like civil war,  
Be blind with tears, and break o'ercharged with grief.  

_Enter a Father that has killed his son, bringing in the body_

**Father**  
Thou that so stoutly hast resisted me,  
Give me thy gold, if thou hast any gold:  
For I have bought it with an hundred blows.  
But let me see: is this our foeman's face?  
Ah, no, no, no, it is mine only son!  
Ah, boy, if any life be left in thee,  
Throw up thine eye! see, see what showers arise,  
Blown with the windy tempest of my heart,  
Upon thy words, that kill mine eye and heart!  
O, pity, God, this miserable age!  
What stratagems, how fell, how butcherly,  
Erroneous, mutinous and unnatural,  
This deadly quarrel daily doth beget!  
O boy, thy father gave thee life too soon,  
And hath bereft thee of thy life too late!  

**KING HENRY VI**  
Woe above woe! grief more than common grief!  
O that my death would stay these ruthful deeds!  
O pity, pity, gentle heaven, pity!  
The red rose and the white are on his face,  
The fatal colours of our striving houses:  
The one his purple blood right well resembles;  
The other his pale cheeks, methinks, presenteth:  
Wither one rose, and let the other flourish;  
If you contend, a thousand lives must wither.  

**Son**  
How will my mother for a father's death  
Take on with me and ne'er be satisfied!  

**Father**  
How will my wife for slaughter of my son  
Shed seas of tears and ne'er be satisfied!  

**KING HENRY VI**  
How will the country for these woful chances  
Misthink the king and not be satisfied!  

**Son**  
Was ever son so rued a father's death?  

**Father**  
Was ever father so bemoan'd his son?  

**KING HENRY VI**  
Was ever king so grieved for subjects' woe?  
Much is your sorrow; mine ten times so much.  

**Son**  
I'll bear thee hence, where I may weep my fill.  

_Exit with the body_

**Father**  
These arms of mine shall be thy winding-sheet;  
My heart, sweet boy, shall be thy sepulchre,  
For from my heart thine image ne'er shall go;  
My sighing breast shall be thy funeral bell;  
And so obsequious will thy father be,  
Even for the loss of thee, having no more,  
As Priam was for all his valiant sons.  
I'll bear thee hence; and let them fight that will,  
For I have murdered where I should not kill.  

_Exit with the body_

**KING HENRY VI**  
Sad-hearted men, much overgone with care,  
Here sits a king more woful than you are.  

_Alarums: excursions. Enter QUEEN MARGARET, PRINCE EDWARD, and EXETER_

**PRINCE EDWARD**  
Fly, father, fly! for all your friends are fled,  
And Warwick rages like a chafed bull:  
Away! for death doth hold us in pursuit.  

**QUEEN MARGARET**  
Mount you, my lord; towards Berwick post amain:  
Edward and Richard, like a brace of greyhounds  
Having the fearful flying hare in sight,  
With fiery eyes sparkling for very wrath,  
And bloody steel grasp'd in their ireful hands,  
Are at our backs; and therefore hence amain.  

**EXETER**  
Away! for vengeance comes along with them:  
Nay, stay not to expostulate, make speed;  
Or else come after: I'll away before.  

**KING HENRY VI**  
Nay, take me with thee, good sweet Exeter:  
Not that I fear to stay, but love to go  
Whither the queen intends. Forward; away!  

_Exeunt_

### SCENE VI. Another part of the field.

_A loud alarum. Enter CLIFFORD, wounded_

**CLIFFORD**  
Here burns my candle out; ay, here it dies,  
Which, whiles it lasted, gave King Henry light.  
O Lancaster, I fear thy overthrow  
More than my body's parting with my soul!  
My love and fear glued many friends to thee;  
And, now I fall, thy tough commixture melts.  
Impairing Henry, strengthening misproud York,  
The common people swarm like summer flies;  
And whither fly the gnats but to the sun?  
And who shines now but Henry's enemies?  
O Phoebus, hadst thou never given consent  
That Phaethon should cheque thy fiery steeds,  
Thy burning car never had scorch'd the earth!  
And, Henry, hadst thou sway'd as kings should do,  
Or as thy father and his father did,  
Giving no ground unto the house of York,  
They never then had sprung like summer flies;  
I and ten thousand in this luckless realm  
Had left no mourning widows for our death;  
And thou this day hadst kept thy chair in peace.  
For what doth cherish weeds but gentle air?  
And what makes robbers bold but too much lenity?  
Bootless are plaints, and cureless are my wounds;  
No way to fly, nor strength to hold out flight:  
The foe is merciless, and will not pity;  
For at their hands I have deserved no pity.  
The air hath got into my deadly wounds,  
And much effuse of blood doth make me faint.  
Come, York and Richard, Warwick and the rest;  
I stabb'd your fathers' bosoms, split my breast.  

_He faints_

_Alarum and retreat. Enter EDWARD, GEORGE, RICHARD, MONTAGUE, WARWICK, and
Soldiers_

**EDWARD**  
Now breathe we, lords: good fortune bids us pause,  
And smooth the frowns of war with peaceful looks.  
Some troops pursue the bloody-minded queen,  
That led calm Henry, though he were a king,  
As doth a sail, fill'd with a fretting gust,  
Command an argosy to stem the waves.  
But think you, lords, that Clifford fled with them?  

**WARWICK**  
No, 'tis impossible he should escape,  
For, though before his face I speak the words  
Your brother Richard mark'd him for the grave:  
And wheresoe'er he is, he's surely dead.  

_CLIFFORD groans, and dies_

**EDWARD**  
Whose soul is that which takes her heavy leave?  

**RICHARD**  
A deadly groan, like life and death's departing.  

**EDWARD**  
See who it is: and, now the battle's ended,  
If friend or foe, let him be gently used.  

**RICHARD**  
Revoke that doom of mercy, for 'tis Clifford;  
Who not contented that he lopp'd the branch  
In hewing Rutland when his leaves put forth,  
But set his murdering knife unto the root  
From whence that tender spray did sweetly spring,  
I mean our princely father, Duke of York.  

**WARWICK**  
From off the gates of York fetch down the head,  
Your father's head, which Clifford placed there;  
Instead whereof let this supply the room:  
Measure for measure must be answered.  

**EDWARD**  
Bring forth that fatal screech-owl to our house,  
That nothing sung but death to us and ours:  
Now death shall stop his dismal threatening sound,  
And his ill-boding tongue no more shall speak.  

**WARWICK**  
I think his understanding is bereft.  
Speak, Clifford, dost thou know who speaks to thee?  
Dark cloudy death o'ershades his beams of life,  
And he nor sees nor hears us what we say.  

**RICHARD**  
O, would he did! and so perhaps he doth:  
'Tis but his policy to counterfeit,  
Because he would avoid such bitter taunts  
Which in the time of death he gave our father.  

**GEORGE**  
If so thou think'st, vex him with eager words.  

**RICHARD**  
Clifford, ask mercy and obtain no grace.  

**EDWARD**  
Clifford, repent in bootless penitence.  

**WARWICK**  
Clifford, devise excuses for thy faults.  

**GEORGE**  
While we devise fell tortures for thy faults.  

**RICHARD**  
Thou didst love York, and I am son to York.  

**EDWARD**  
Thou pitied'st Rutland; I will pity thee.  

**GEORGE**  
Where's Captain Margaret, to fence you now?  

**WARWICK**  
They mock thee, Clifford: swear as thou wast wont.  

**RICHARD**  
What, not an oath? nay, then the world goes hard  
When Clifford cannot spare his friends an oath.  
I know by that he's dead; and, by my soul,  
If this right hand would buy two hour's life,  
That I in all despite might rail at him,  
This hand should chop it off, and with the  
issuing blood  
Stifle the villain whose unstanched thirst  
York and young Rutland could not satisfy.  

**WARWICK**  
Ay, but he's dead: off with the traitor's head,  
And rear it in the place your father's stands.  
And now to London with triumphant march,  
There to be crowned England's royal king:  
From whence shall Warwick cut the sea to France,  
And ask the Lady Bona for thy queen:  
So shalt thou sinew both these lands together;  
And, having France thy friend, thou shalt not dread  
The scatter'd foe that hopes to rise again;  
For though they cannot greatly sting to hurt,  
Yet look to have them buzz to offend thine ears.  
First will I see the coronation;  
And then to Brittany I'll cross the sea,  
To effect this marriage, so it please my lord.  

**EDWARD**  
Even as thou wilt, sweet Warwick, let it be;  
For in thy shoulder do I build my seat,  
And never will I undertake the thing  
Wherein thy counsel and consent is wanting.  
Richard, I will create thee Duke of Gloucester,  
And George, of Clarence: Warwick, as ourself,  
Shall do and undo as him pleaseth best.  

**RICHARD**  
Let me be Duke of Clarence, George of Gloucester;  
For Gloucester's dukedom is too ominous.  

**WARWICK**  
Tut, that's a foolish observation:  
Richard, be Duke of Gloucester. Now to London,  
To see these honours in possession.  

_Exeunt_

# ACT III

### SCENE I. A forest in the north of England.

_Enter two Keepers, with cross-bows in their hands_

**First Keeper**  
Under this thick-grown brake we'll shroud ourselves;  
For through this laund anon the deer will come;  
And in this covert will we make our stand,  
Culling the principal of all the deer.  

**Second Keeper**  
I'll stay above the hill, so both may shoot.  

**First Keeper**  
That cannot be; the noise of thy cross-bow  
Will scare the herd, and so my shoot is lost.  
Here stand we both, and aim we at the best:  
And, for the time shall not seem tedious,  
I'll tell thee what befell me on a day  
In this self-place where now we mean to stand.  

**Second Keeper**  
Here comes a man; let's stay till he be past.  

_Enter KING HENRY VI, disguised, with a prayerbook_

**KING HENRY VI**  
From Scotland am I stol'n, even of pure love,  
To greet mine own land with my wishful sight.  
No, Harry, Harry, 'tis no land of thine;  
Thy place is fill'd, thy sceptre wrung from thee,  
Thy balm wash'd off wherewith thou wast anointed:  
No bending knee will call thee Caesar now,  
No humble suitors press to speak for right,  
No, not a man comes for redress of thee;  
For how can I help them, and not myself?  

**First Keeper**  
Ay, here's a deer whose skin's a keeper's fee:  
This is the quondam king; let's seize upon him.  

**KING HENRY VI**  
Let me embrace thee, sour adversity,  
For wise men say it is the wisest course.  

**Second Keeper**  
Why linger we? let us lay hands upon him.  

**First Keeper**  
Forbear awhile; we'll hear a little more.  

**KING HENRY VI**  
My queen and son are gone to France for aid;  
And, as I hear, the great commanding Warwick  
Is thither gone, to crave the French king's sister  
To wife for Edward: if this news be true,  
Poor queen and son, your labour is but lost;  
For Warwick is a subtle orator,  
And Lewis a prince soon won with moving words.  
By this account then Margaret may win him;  
For she's a woman to be pitied much:  
Her sighs will make a battery in his breast;  
Her tears will pierce into a marble heart;  
The tiger will be mild whiles she doth mourn;  
And Nero will be tainted with remorse,  
To hear and see her plaints, her brinish tears.  
Ay, but she's come to beg, Warwick to give;  
She, on his left side, craving aid for Henry,  
He, on his right, asking a wife for Edward.  
She weeps, and says her Henry is deposed;  
He smiles, and says his Edward is install'd;  
That she, poor wretch, for grief can speak no more;  
Whiles Warwick tells his title, smooths the wrong,  
Inferreth arguments of mighty strength,  
And in conclusion wins the king from her,  
With promise of his sister, and what else,  
To strengthen and support King Edward's place.  
O Margaret, thus 'twill be; and thou, poor soul,  
Art then forsaken, as thou went'st forlorn!  

**Second Keeper**  
Say, what art thou that talk'st of kings and queens?  

**KING HENRY VI**  
More than I seem, and less than I was born to:  
A man at least, for less I should not be;  
And men may talk of kings, and why not I?  

**Second Keeper**  
Ay, but thou talk'st as if thou wert a king.  

**KING HENRY VI**  
Why, so I am, in mind; and that's enough.  

**Second Keeper**  
But, if thou be a king, where is thy crown?  

**KING HENRY VI**  
My crown is in my heart, not on my head;  
Not decked with diamonds and Indian stones,  
Nor to be seen: my crown is called content:  
A crown it is that seldom kings enjoy.  

**Second Keeper**  
Well, if you be a king crown'd with content,  
Your crown content and you must be contented  
To go along with us; for as we think,  
You are the king King Edward hath deposed;  
And we his subjects sworn in all allegiance  
Will apprehend you as his enemy.  

**KING HENRY VI**  
But did you never swear, and break an oath?  

**Second Keeper**  
No, never such an oath; nor will not now.  

**KING HENRY VI**  
Where did you dwell when I was King of England?  

**Second Keeper**  
Here in this country, where we now remain.  

**KING HENRY VI**  
I was anointed king at nine months old;  
My father and my grandfather were kings,  
And you were sworn true subjects unto me:  
And tell me, then, have you not broke your oaths?  

**First Keeper**  
No;  
For we were subjects but while you were king.  

**KING HENRY VI**  
Why, am I dead? do I not breathe a man?  
Ah, simple men, you know not what you swear!  
Look, as I blow this feather from my face,  
And as the air blows it to me again,  
Obeying with my wind when I do blow,  
And yielding to another when it blows,  
Commanded always by the greater gust;  
Such is the lightness of you common men.  
But do not break your oaths; for of that sin  
My mild entreaty shall not make you guilty.  
Go where you will, the king shall be commanded;  
And be you kings, command, and I'll obey.  

**First Keeper**  
We are true subjects to the king, King Edward.  

**KING HENRY VI**  
So would you be again to Henry,  
If he were seated as King Edward is.  

**First Keeper**  
We charge you, in God's name, and the king's,  
To go with us unto the officers.  

**KING HENRY VI**  
In God's name, lead; your king's name be obey'd:  
And what God will, that let your king perform;  
And what he will, I humbly yield unto.  

_Exeunt_

### SCENE II. London. The palace.

_Enter KING EDWARD IV, GLOUCESTER, CLARENCE, and LADY GREY_

**KING EDWARD IV**  
Brother of Gloucester, at Saint Alban's field  
This lady's husband, Sir Richard Grey, was slain,  
His lands then seized on by the conqueror:  
Her suit is now to repossess those lands;  
Which we in justice cannot well deny,  
Because in quarrel of the house of York  
The worthy gentleman did lose his life.  

**GLOUCESTER**  
Your highness shall do well to grant her suit;  
It were dishonour to deny it her.  

**KING EDWARD IV**  
It were no less; but yet I'll make a pause.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
Yea, is it so?  
I see the lady hath a thing to grant,  
Before the king will grant her humble suit.  

**CLARENCE**  
_[Aside to GLOUCESTER]_  
He knows the game: how true  
he keeps the wind!  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
Silence!  

**KING EDWARD IV**  
Widow, we will consider of your suit;  
And come some other time to know our mind.  

**LADY GREY**  
Right gracious lord, I cannot brook delay:  
May it please your highness to resolve me now;  
And what your pleasure is, shall satisfy me.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
Ay, widow? then I'll warrant  
you all your lands,  
An if what pleases him shall pleasure you.  
Fight closer, or, good faith, you'll catch a blow.  

**CLARENCE**  
_[Aside to GLOUCESTER]_  
I fear her not, unless she  
chance to fall.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
God forbid that! for he'll  
take vantages.  

**KING EDWARD IV**  
How many children hast thou, widow? tell me.  

**CLARENCE**  
_[Aside to GLOUCESTER]_  
I think he means to beg a  
child of her.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
Nay, whip me then: he'll rather  
give her two.  

**LADY GREY**  
Three, my most gracious lord.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
You shall have four, if you'll  
be ruled by him.  

**KING EDWARD IV**  
'Twere pity they should lose their father's lands.  

**LADY GREY**  
Be pitiful, dread lord, and grant it then.  

**KING EDWARD IV**  
Lords, give us leave: I'll try this widow's wit.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
Ay, good leave have you; for  
you will have leave,  
Till youth take leave and leave you to the crutch.  

_GLOUCESTER and CLARENCE retire_

**KING EDWARD IV**  
Now tell me, madam, do you love your children?  

**LADY GREY**  
Ay, full as dearly as I love myself.  

**KING EDWARD IV**  
And would you not do much to do them good?  

**LADY GREY**  
To do them good, I would sustain some harm.  

**KING EDWARD IV**  
Then get your husband's lands, to do them good.  

**LADY GREY**  
Therefore I came unto your majesty.  

**KING EDWARD IV**  
I'll tell you how these lands are to be got.  

**LADY GREY**  
So shall you bind me to your highness' service.  

**KING EDWARD IV**  
What service wilt thou do me, if I give them?  

**LADY GREY**  
What you command, that rests in me to do.  

**KING EDWARD IV**  
But you will take exceptions to my boon.  

**LADY GREY**  
No, gracious lord, except I cannot do it.  

**KING EDWARD IV**  
Ay, but thou canst do what I mean to ask.  

**LADY GREY**  
Why, then I will do what your grace commands.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
He plies her hard; and much rain  
wears the marble.  

**CLARENCE**  
_[Aside to GLOUCESTER]_  
As red as fire! nay, then  
her wax must melt.  

**LADY GREY**  
Why stops my lord, shall I not hear my task?  

**KING EDWARD IV**  
An easy task; 'tis but to love a king.  

**LADY GREY**  
That's soon perform'd, because I am a subject.  

**KING EDWARD IV**  
Why, then, thy husband's lands I freely give thee.  

**LADY GREY**  
I take my leave with many thousand thanks.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
The match is made; she seals it  
with a curtsy.  

**KING EDWARD IV**  
But stay thee, 'tis the fruits of love I mean.  

**LADY GREY**  
The fruits of love I mean, my loving liege.  

**KING EDWARD IV**  
Ay, but, I fear me, in another sense.  
What love, think'st thou, I sue so much to get?  

**LADY GREY**  
My love till death, my humble thanks, my prayers;  
That love which virtue begs and virtue grants.  

**KING EDWARD IV**  
No, by my troth, I did not mean such love.  

**LADY GREY**  
Why, then you mean not as I thought you did.  

**KING EDWARD IV**  
But now you partly may perceive my mind.  

**LADY GREY**  
My mind will never grant what I perceive  
Your highness aims at, if I aim aright.  

**KING EDWARD IV**  
To tell thee plain, I aim to lie with thee.  

**LADY GREY**  
To tell you plain, I had rather lie in prison.  

**KING EDWARD IV**  
Why, then thou shalt not have thy husband's lands.  

**LADY GREY**  
Why, then mine honesty shall be my dower;  
For by that loss I will not purchase them.  

**KING EDWARD IV**  
Therein thou wrong'st thy children mightily.  

**LADY GREY**  
Herein your highness wrongs both them and me.  
But, mighty lord, this merry inclination  
Accords not with the sadness of my suit:  
Please you dismiss me either with 'ay' or 'no.'  

**KING EDWARD IV**  
Ay, if thou wilt say 'ay' to my request;  
No if thou dost say 'no' to my demand.  

**LADY GREY**  
Then, no, my lord. My suit is at an end.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
The widow likes him not, she  
knits her brows.  

**CLARENCE**  
_[Aside to GLOUCESTER]_  
He is the bluntest wooer in  
Christendom.  

**KING EDWARD IV**  
_[Aside]_  
Her looks do argue her replete with modesty;  
Her words do show her wit incomparable;  
All her perfections challenge sovereignty:  
One way or other, she is for a king;  
And she shall be my love, or else my queen.--  
Say that King Edward take thee for his queen?  

**LADY GREY**  
'Tis better said than done, my gracious lord:  
I am a subject fit to jest withal,  
But far unfit to be a sovereign.  

**KING EDWARD IV**  
Sweet widow, by my state I swear to thee  
I speak no more than what my soul intends;  
And that is, to enjoy thee for my love.  

**LADY GREY**  
And that is more than I will yield unto:  
I know I am too mean to be your queen,  
And yet too good to be your concubine.  

**KING EDWARD IV**  
You cavil, widow: I did mean, my queen.  

**LADY GREY**  
'Twill grieve your grace my sons should call you father.  

**KING EDWARD IV**  
No more than when my daughters call thee mother.  
Thou art a widow, and thou hast some children;  
And, by God's mother, I, being but a bachelor,  
Have other some: why, 'tis a happy thing  
To be the father unto many sons.  
Answer no more, for thou shalt be my queen.  

**GLOUCESTER**  
_[Aside to CLARENCE]_  
The ghostly father now hath done  
his shrift.  

**CLARENCE**  
_[Aside to GLOUCESTER]_  
When he was made a shriver,  
'twas for shift.  

**KING EDWARD IV**  
Brothers, you muse what chat we two have had.  

**GLOUCESTER**  
The widow likes it not, for she looks very sad.  

**KING EDWARD IV**  
You'll think it strange if I should marry her.  

**CLARENCE**  
To whom, my lord?  

**KING EDWARD IV**  
Why, Clarence, to myself.  

**GLOUCESTER**  
That would be ten days' wonder at the least.  

**CLARENCE**  
That's a day longer than a wonder lasts.  

**GLOUCESTER**  
By so much is the wonder in extremes.  

**KING EDWARD IV**  
Well, jest on, brothers: I can tell you both  
Her suit is granted for her husband's lands.  

_Enter a Nobleman_

**Nobleman**  
My gracious lord, Henry your foe is taken,  
And brought your prisoner to your palace gate.  

**KING EDWARD IV**  
See that he be convey'd unto the Tower:  
And go we, brothers, to the man that took him,  
To question of his apprehension.  
Widow, go you along. Lords, use her honourably.  

_Exeunt all but GLOUCESTER_

**GLOUCESTER**  
Ay, Edward will use women honourably.  
Would he were wasted, marrow, bones and all,  
That from his loins no hopeful branch may spring,  
To cross me from the golden time I look for!  
And yet, between my soul's desire and me--  
The lustful Edward's title buried--  
Is Clarence, Henry, and his son young Edward,  
And all the unlook'd for issue of their bodies,  
To take their rooms, ere I can place myself:  
A cold premeditation for my purpose!  
Why, then, I do but dream on sovereignty;  
Like one that stands upon a promontory,  
And spies a far-off shore where he would tread,  
Wishing his foot were equal with his eye,  
And chides the sea that sunders him from thence,  
Saying, he'll lade it dry to have his way:  
So do I wish the crown, being so far off;  
And so I chide the means that keeps me from it;  
And so I say, I'll cut the causes off,  
Flattering me with impossibilities.  
My eye's too quick, my heart o'erweens too much,  
Unless my hand and strength could equal them.  
Well, say there is no kingdom then for Richard;  
What other pleasure can the world afford?  
I'll make my heaven in a lady's lap,  
And deck my body in gay ornaments,  
And witch sweet ladies with my words and looks.  
O miserable thought! and more unlikely  
Than to accomplish twenty golden crowns!  
Why, love forswore me in my mother's womb:  
And, for I should not deal in her soft laws,  
She did corrupt frail nature with some bribe,  
To shrink mine arm up like a wither'd shrub;  
To make an envious mountain on my back,  
Where sits deformity to mock my body;  
To shape my legs of an unequal size;  
To disproportion me in every part,  
Like to a chaos, or an unlick'd bear-whelp  
That carries no impression like the dam.  
And am I then a man to be beloved?  
O monstrous fault, to harbour such a thought!  
Then, since this earth affords no joy to me,  
But to command, to cheque, to o'erbear such  
As are of better person than myself,  
I'll make my heaven to dream upon the crown,  
And, whiles I live, to account this world but hell,  
Until my mis-shaped trunk that bears this head  
Be round impaled with a glorious crown.  
And yet I know not how to get the crown,  
For many lives stand between me and home:  
And I,--like one lost in a thorny wood,  
That rends the thorns and is rent with the thorns,  
Seeking a way and straying from the way;  
Not knowing how to find the open air,  
But toiling desperately to find it out,--  
Torment myself to catch the English crown:  
And from that torment I will free myself,  
Or hew my way out with a bloody axe.  
Why, I can smile, and murder whiles I smile,  
And cry 'Content' to that which grieves my heart,  
And wet my cheeks with artificial tears,  
And frame my face to all occasions.  
I'll drown more sailors than the mermaid shall;  
I'll slay more gazers than the basilisk;  
I'll play the orator as well as Nestor,  
Deceive more slily than Ulysses could,  
And, like a Sinon, take another Troy.  
I can add colours to the chameleon,  
Change shapes with Proteus for advantages,  
And set the murderous Machiavel to school.  
Can I do this, and cannot get a crown?  
Tut, were it farther off, I'll pluck it down.  

_Exit_

### SCENE III. France. KING LEWIS XI's palace.

_Flourish. Enter KING LEWIS XI, his sister BONA, his Admiral, called
BOURBON, PRINCE EDWARD, QUEEN MARGARET, and OXFORD. KING LEWIS XI sits, and
riseth up again_

**KING LEWIS XI**  
Fair Queen of England, worthy Margaret,  
Sit down with us: it ill befits thy state  
And birth, that thou shouldst stand while Lewis doth sit.  

**QUEEN MARGARET**  
No, mighty King of France: now Margaret  
Must strike her sail and learn awhile to serve  
Where kings command. I was, I must confess,  
Great Albion's queen in former golden days:  
But now mischance hath trod my title down,  
And with dishonour laid me on the ground;  
Where I must take like seat unto my fortune,  
And to my humble seat conform myself.  

**KING LEWIS XI**  
Why, say, fair queen, whence springs this deep despair?  

**QUEEN MARGARET**  
From such a cause as fills mine eyes with tears  
And stops my tongue, while heart is drown'd in cares.  

**KING LEWIS XI**  
Whate'er it be, be thou still like thyself,  
And sit thee by our side:  

_Seats her by him_

Yield not thy neck  
To fortune's yoke, but let thy dauntless mind  
Still ride in triumph over all mischance.  
Be plain, Queen Margaret, and tell thy grief;  
It shall be eased, if France can yield relief.  

**QUEEN MARGARET**  
Those gracious words revive my drooping thoughts  
And give my tongue-tied sorrows leave to speak.  
Now, therefore, be it known to noble Lewis,  
That Henry, sole possessor of my love,  
Is of a king become a banish'd man,  
And forced to live in Scotland a forlorn;  
While proud ambitious Edward Duke of York  
Usurps the regal title and the seat  
Of England's true-anointed lawful king.  
This is the cause that I, poor Margaret,  
With this my son, Prince Edward, Henry's heir,  
Am come to crave thy just and lawful aid;  
And if thou fail us, all our hope is done:  
Scotland hath will to help, but cannot help;  
Our people and our peers are both misled,  
Our treasures seized, our soldiers put to flight,  
And, as thou seest, ourselves in heavy plight.  

**KING LEWIS XI**  
Renowned queen, with patience calm the storm,  
While we bethink a means to break it off.  

**QUEEN MARGARET**  
The more we stay, the stronger grows our foe.  

**KING LEWIS XI**  
The more I stay, the more I'll succor thee.  

**QUEEN MARGARET**  
O, but impatience waiteth on true sorrow.  
And see where comes the breeder of my sorrow!  

_Enter WARWICK_

**KING LEWIS XI**  
What's he approacheth boldly to our presence?  

**QUEEN MARGARET**  
Our Earl of Warwick, Edward's greatest friend.  

**KING LEWIS XI**  
Welcome, brave Warwick! What brings thee to France?  

_He descends. She ariseth_

**QUEEN MARGARET**  
Ay, now begins a second storm to rise;  
For this is he that moves both wind and tide.  

**WARWICK**  
From worthy Edward, King of Albion,  
My lord and sovereign, and thy vowed friend,  
I come, in kindness and unfeigned love,  
First, to do greetings to thy royal person;  
And then to crave a league of amity;  
And lastly, to confirm that amity  
With a nuptial knot, if thou vouchsafe to grant  
That virtuous Lady Bona, thy fair sister,  
To England's king in lawful marriage.  

**QUEEN MARGARET**  
_[Aside]_  
If that go forward, Henry's hope is done.  

**WARWICK**  
_[To BONA]_  
And, gracious madam, in our king's behalf,  
I am commanded, with your leave and favour,  
Humbly to kiss your hand, and with my tongue  
To tell the passion of my sovereign's heart;  
Where fame, late entering at his heedful ears,  
Hath placed thy beauty's image and thy virtue.  

**QUEEN MARGARET**  
King Lewis and Lady Bona, hear me speak,  
Before you answer Warwick. His demand  
Springs not from Edward's well-meant honest love,  
But from deceit bred by necessity;  
For how can tyrants safely govern home,  
Unless abroad they purchase great alliance?  
To prove him tyrant this reason may suffice,  
That Henry liveth still: but were he dead,  
Yet here Prince Edward stands, King Henry's son.  
Look, therefore, Lewis, that by this league and marriage  
Thou draw not on thy danger and dishonour;  
For though usurpers sway the rule awhile,  
Yet heavens are just, and time suppresseth wrongs.  

**WARWICK**  
Injurious Margaret!  

**PRINCE EDWARD**  
And why not queen?  

**WARWICK**  
Because thy father Henry did usurp;  
And thou no more are prince than she is queen.  

**OXFORD**  
Then Warwick disannuls great John of Gaunt,  
Which did subdue the greatest part of Spain;  
And, after John of Gaunt, Henry the Fourth,  
Whose wisdom was a mirror to the wisest;  
And, after that wise prince, Henry the Fifth,  
Who by his prowess conquered all France:  
From these our Henry lineally descends.  

**WARWICK**  
Oxford, how haps it, in this smooth discourse,  
You told not how Henry the Sixth hath lost  
All that which Henry Fifth had gotten?  
Methinks these peers of France should smile at that.  
But for the rest, you tell a pedigree  
Of threescore and two years; a silly time  
To make prescription for a kingdom's worth.  

**OXFORD**  
Why, Warwick, canst thou speak against thy liege,  
Whom thou obeyed'st thirty and six years,  
And not bewray thy treason with a blush?  

**WARWICK**  
Can Oxford, that did ever fence the right,  
Now buckler falsehood with a pedigree?  
For shame! leave Henry, and call Edward king.  

**OXFORD**  
Call him my king by whose injurious doom  
My elder brother, the Lord Aubrey Vere,  
Was done to death? and more than so, my father,  
Even in the downfall of his mellow'd years,  
When nature brought him to the door of death?  
No, Warwick, no; while life upholds this arm,  
This arm upholds the house of Lancaster.  

**WARWICK**  
And I the house of York.  

**KING LEWIS XI**  
Queen Margaret, Prince Edward, and Oxford,  
Vouchsafe, at our request, to stand aside,  
While I use further conference with Warwick.  

_They stand aloof_

**QUEEN MARGARET**  
Heavens grant that Warwick's words bewitch him not!  

**KING LEWIS XI**  
Now Warwick, tell me, even upon thy conscience,  
Is Edward your true king? for I were loath  
To link with him that were not lawful chosen.  

**WARWICK**  
Thereon I pawn my credit and mine honour.  

**KING LEWIS XI**  
But is he gracious in the people's eye?  

**WARWICK**  
The more that Henry was unfortunate.  

**KING LEWIS XI**  
Then further, all dissembling set aside,  
Tell me for truth the measure of his love  
Unto our sister Bona.  

**WARWICK**  
Such it seems  
As may beseem a monarch like himself.  
Myself have often heard him say and swear  
That this his love was an eternal plant,  
Whereof the root was fix'd in virtue's ground,  
The leaves and fruit maintain'd with beauty's sun,  
Exempt from envy, but not from disdain,  
Unless the Lady Bona quit his pain.  

**KING LEWIS XI**  
Now, sister, let us hear your firm resolve.  

**BONA**  
Your grant, or your denial, shall be mine:  

_To WARWICK_

Yet I confess that often ere this day,  
When I have heard your king's desert recounted,  
Mine ear hath tempted judgment to desire.  

**KING LEWIS XI**  
Then, Warwick, thus: our sister shall be Edward's;  
And now forthwith shall articles be drawn  
Touching the jointure that your king must make,  
Which with her dowry shall be counterpoised.  
Draw near, Queen Margaret, and be a witness  
That Bona shall be wife to the English king.  

**PRINCE EDWARD**  
To Edward, but not to the English king.  

**QUEEN MARGARET**  
Deceitful Warwick! it was thy device  
By this alliance to make void my suit:  
Before thy coming Lewis was Henry's friend.  

**KING LEWIS XI**  
And still is friend to him and Margaret:  
But if your title to the crown be weak,  
As may appear by Edward's good success,  
Then 'tis but reason that I be released  
From giving aid which late I promised.  
Yet shall you have all kindness at my hand  
That your estate requires and mine can yield.  

**WARWICK**  
Henry now lives in Scotland at his ease,  
Where having nothing, nothing can he lose.  
And as for you yourself, our quondam queen,  
You have a father able to maintain you;  
And better 'twere you troubled him than France.  

**QUEEN MARGARET**  
Peace, impudent and shameless Warwick, peace,  
Proud setter up and puller down of kings!  
I will not hence, till, with my talk and tears,  
Both full of truth, I make King Lewis behold  
Thy sly conveyance and thy lord's false love;  
For both of you are birds of selfsame feather.  

_Post blows a horn within_

**KING LEWIS XI**  
Warwick, this is some post to us or thee.  

_Enter a Post_

**Post**  
_[To WARWICK]_  
My lord ambassador, these letters are for you,  
Sent from your brother, Marquess Montague:  

_To KING LEWIS XI_

These from our king unto your majesty:  

_To QUEEN MARGARET_

And, madam, these for you; from whom I know not.  

_They all read their letters_

**OXFORD**  
I like it well that our fair queen and mistress  
Smiles at her news, while Warwick frowns at his.  

**PRINCE EDWARD**  
Nay, mark how Lewis stamps, as he were nettled:  
I hope all's for the best.  

**KING LEWIS XI**  
Warwick, what are thy news? and yours, fair queen?  

**QUEEN MARGARET**  
Mine, such as fill my heart with unhoped joys.  

**WARWICK**  
Mine, full of sorrow and heart's discontent.  

**KING LEWIS XI**  
What! has your king married the Lady Grey!  
And now, to soothe your forgery and his,  
Sends me a paper to persuade me patience?  
Is this the alliance that he seeks with France?  
Dare he presume to scorn us in this manner?  

**QUEEN MARGARET**  
I told your majesty as much before:  
This proveth Edward's love and Warwick's honesty.  

**WARWICK**  
King Lewis, I here protest, in sight of heaven,  
And by the hope I have of heavenly bliss,  
That I am clear from this misdeed of Edward's,  
No more my king, for he dishonours me,  
But most himself, if he could see his shame.  
Did I forget that by the house of York  
My father came untimely to his death?  
Did I let pass the abuse done to my niece?  
Did I impale him with the regal crown?  
Did I put Henry from his native right?  
And am I guerdon'd at the last with shame?  
Shame on himself! for my desert is honour:  
And to repair my honour lost for him,  
I here renounce him and return to Henry.  
My noble queen, let former grudges pass,  
And henceforth I am thy true servitor:  
I will revenge his wrong to Lady Bona,  
And replant Henry in his former state.  

**QUEEN MARGARET**  
Warwick, these words have turn'd my hate to love;  
And I forgive and quite forget old faults,  
And joy that thou becomest King Henry's friend.  

**WARWICK**  
So much his friend, ay, his unfeigned friend,  
That, if King Lewis vouchsafe to furnish us  
With some few bands of chosen soldiers,  
I'll undertake to land them on our coast  
And force the tyrant from his seat by war.  
'Tis not his new-made bride shall succor him:  
And as for Clarence, as my letters tell me,  
He's very likely now to fall from him,  
For matching more for wanton lust than honour,  
Or than for strength and safety of our country.  

**BONA**  
Dear brother, how shall Bona be revenged  
But by thy help to this distressed queen?  

**QUEEN MARGARET**  
Renowned prince, how shall poor Henry live,  
Unless thou rescue him from foul despair?  

**BONA**  
My quarrel and this English queen's are one.  

**WARWICK**  
And mine, fair lady Bona, joins with yours.  

**KING LEWIS XI**  
And mine with hers, and thine, and Margaret's.  
Therefore at last I firmly am resolved  
You shall have aid.  

**QUEEN MARGARET**  
Let me give humble thanks for all at once.  

**KING LEWIS XI**  
Then, England's messenger, return in post,  
And tell false Edward, thy supposed king,  
That Lewis of France is sending over masquers  
To revel it with him and his new bride:  
Thou seest what's past, go fear thy king withal.  

**BONA**  
Tell him, in hope he'll prove a widower shortly,  
I'll wear the willow garland for his sake.  

**QUEEN MARGARET**  
Tell him, my mourning weeds are laid aside,  
And I am ready to put armour on.  

**WARWICK**  
Tell him from me that he hath done me wrong,  
And therefore I'll uncrown him ere't be long.  
There's thy reward: be gone.  

_Exit Post_

**KING LEWIS XI**  
But, Warwick,  
Thou and Oxford, with five thousand men,  
Shall cross the seas, and bid false Edward battle;  
And, as occasion serves, this noble queen  
And prince shall follow with a fresh supply.  
Yet, ere thou go, but answer me one doubt,  
What pledge have we of thy firm loyalty?  

**WARWICK**  
This shall assure my constant loyalty,  
That if our queen and this young prince agree,  
I'll join mine eldest daughter and my joy  
To him forthwith in holy wedlock bands.  

**QUEEN MARGARET**  
Yes, I agree, and thank you for your motion.  
Son Edward, she is fair and virtuous,  
Therefore delay not, give thy hand to Warwick;  
And, with thy hand, thy faith irrevocable,  
That only Warwick's daughter shall be thine.  

**PRINCE EDWARD**  
Yes, I accept her, for she well deserves it;  
And here, to pledge my vow, I give my hand.  

_He gives his hand to WARWICK_

**KING LEWIS XI**  
Why stay we now? These soldiers shall be levied,  
And thou, Lord Bourbon, our high admiral,  
Shalt waft them over with our royal fleet.  
I long till Edward fall by war's mischance,  
For mocking marriage with a dame of France.  

_Exeunt all but WARWICK_

**WARWICK**  
I came from Edward as ambassador,  
But I return his sworn and mortal foe:  
Matter of marriage was the charge he gave me,  
But dreadful war shall answer his demand.  
Had he none else to make a stale but me?  
Then none but I shall turn his jest to sorrow.  
I was the chief that raised him to the crown,  
And I'll be chief to bring him down again:  
Not that I pity Henry's misery,  
But seek revenge on Edward's mockery.  

_Exit_

# ACT IV

### SCENE I. London. The palace.

_Enter GLOUCESTER, CLARENCE, SOMERSET, and MONTAGUE_

**GLOUCESTER**  
Now tell me, brother Clarence, what think you  
Of this new marriage with the Lady Grey?  
Hath not our brother made a worthy choice?  

**CLARENCE**  
Alas, you know, 'tis far from hence to France;  
How could he stay till Warwick made return?  

**SOMERSET**  
My lords, forbear this talk; here comes the king.  

**GLOUCESTER**  
And his well-chosen bride.  

**CLARENCE**  
I mind to tell him plainly what I think.  

_Flourish. Enter KING EDWARD IV, attended; QUEEN ELIZABETH, PEMBROKE,
STAFFORD, HASTINGS, and others_

**KING EDWARD IV**  
Now, brother of Clarence, how like you our choice,  
That you stand pensive, as half malcontent?  

**CLARENCE**  
As well as Lewis of France, or the Earl of Warwick,  
Which are so weak of courage and in judgment  
That they'll take no offence at our abuse.  

**KING EDWARD IV**  
Suppose they take offence without a cause,  
They are but Lewis and Warwick: I am Edward,  
Your king and Warwick's, and must have my will.  

**GLOUCESTER**  
And shall have your will, because our king:  
Yet hasty marriage seldom proveth well.  

**KING EDWARD IV**  
Yea, brother Richard, are you offended too?  

**GLOUCESTER**  
Not I:  
No, God forbid that I should wish them sever'd  
Whom God hath join'd together; ay, and 'twere pity  
To sunder them that yoke so well together.  

**KING EDWARD IV**  
Setting your scorns and your mislike aside,  
Tell me some reason why the Lady Grey  
Should not become my wife and England's queen.  
And you too, Somerset and Montague,  
Speak freely what you think.  

**CLARENCE**  
Then this is mine opinion: that King Lewis  
Becomes your enemy, for mocking him  
About the marriage of the Lady Bona.  

**GLOUCESTER**  
And Warwick, doing what you gave in charge,  
Is now dishonoured by this new marriage.  

**KING EDWARD IV**  
What if both Lewis and Warwick be appeased  
By such invention as I can devise?  

**MONTAGUE**  
Yet, to have join'd with France in such alliance  
Would more have strengthen'd this our commonwealth  
'Gainst foreign storms than any home-bred marriage.  

**HASTINGS**  
Why, knows not Montague that of itself  
England is safe, if true within itself?  

**MONTAGUE**  
But the safer when 'tis back'd with France.  

**HASTINGS**  
'Tis better using France than trusting France:  
Let us be back'd with God and with the seas  
Which He hath given for fence impregnable,  
And with their helps only defend ourselves;  
In them and in ourselves our safety lies.  

**CLARENCE**  
For this one speech Lord Hastings well deserves  
To have the heir of the Lord Hungerford.  

**KING EDWARD IV**  
Ay, what of that? it was my will and grant;  
And for this once my will shall stand for law.  

**GLOUCESTER**  
And yet methinks your grace hath not done well,  
To give the heir and daughter of Lord Scales  
Unto the brother of your loving bride;  
She better would have fitted me or Clarence:  
But in your bride you bury brotherhood.  

**CLARENCE**  
Or else you would not have bestow'd the heir  
Of the Lord Bonville on your new wife's son,  
And leave your brothers to go speed elsewhere.  

**KING EDWARD IV**  
Alas, poor Clarence! is it for a wife  
That thou art malcontent? I will provide thee.  

**CLARENCE**  
In choosing for yourself, you show'd your judgment,  
Which being shallow, you give me leave  
To play the broker in mine own behalf;  
And to that end I shortly mind to leave you.  

**KING EDWARD IV**  
Leave me, or tarry, Edward will be king,  
And not be tied unto his brother's will.  

**QUEEN ELIZABETH**  
My lords, before it pleased his majesty  
To raise my state to title of a queen,  
Do me but right, and you must all confess  
That I was not ignoble of descent;  
And meaner than myself have had like fortune.  
But as this title honours me and mine,  
So your dislike, to whom I would be pleasing,  
Doth cloud my joys with danger and with sorrow.  

**KING EDWARD IV**  
My love, forbear to fawn upon their frowns:  
What danger or what sorrow can befall thee,  
So long as Edward is thy constant friend,  
And their true sovereign, whom they must obey?  
Nay, whom they shall obey, and love thee too,  
Unless they seek for hatred at my hands;  
Which if they do, yet will I keep thee safe,  
And they shall feel the vengeance of my wrath.  

**GLOUCESTER**  
_[Aside]_  
I hear, yet say not much, but think the more.  

_Enter a Post_

**KING EDWARD IV**  
Now, messenger, what letters or what news  
From France?  

**Post**  
My sovereign liege, no letters; and few words,  
But such as I, without your special pardon,  
Dare not relate.  

**KING EDWARD IV**  
Go to, we pardon thee: therefore, in brief,  
Tell me their words as near as thou canst guess them.  
What answer makes King Lewis unto our letters?  

**Post**  
At my depart, these were his very words:  
'Go tell false Edward, thy supposed king,  
That Lewis of France is sending over masquers  
To revel it with him and his new bride.'  

**KING EDWARD IV**  
Is Lewis so brave? belike he thinks me Henry.  
But what said Lady Bona to my marriage?  

**Post**  
These were her words, utter'd with mad disdain:  
'Tell him, in hope he'll prove a widower shortly,  
I'll wear the willow garland for his sake.'  

**KING EDWARD IV**  
I blame not her, she could say little less;  
She had the wrong. But what said Henry's queen?  
For I have heard that she was there in place.  

**Post**  
'Tell him,' quoth she, 'my mourning weeds are done,  
And I am ready to put armour on.'  

**KING EDWARD IV**  
Belike she minds to play the Amazon.  
But what said Warwick to these injuries?  

**Post**  
He, more incensed against your majesty  
Than all the rest, discharged me with these words:  
'Tell him from me that he hath done me wrong,  
And therefore I'll uncrown him ere't be long.'  

**KING EDWARD IV**  
Ha! durst the traitor breathe out so proud words?  
Well I will arm me, being thus forewarn'd:  
They shall have wars and pay for their presumption.  
But say, is Warwick friends with Margaret?  

**Post**  
Ay, gracious sovereign; they are so link'd in  
friendship  
That young Prince Edward marries Warwick's daughter.  

**CLARENCE**  
Belike the elder; Clarence will have the younger.  
Now, brother king, farewell, and sit you fast,  
For I will hence to Warwick's other daughter;  
That, though I want a kingdom, yet in marriage  
I may not prove inferior to yourself.  
You that love me and Warwick, follow me.  

_Exit CLARENCE, and SOMERSET follows_

**GLOUCESTER**  
_[Aside]_  
Not I:  
My thoughts aim at a further matter; I  
Stay not for the love of Edward, but the crown.  

**KING EDWARD IV**  
Clarence and Somerset both gone to Warwick!  
Yet am I arm'd against the worst can happen;  
And haste is needful in this desperate case.  
Pembroke and Stafford, you in our behalf  
Go levy men, and make prepare for war;  
They are already, or quickly will be landed:  
Myself in person will straight follow you.  

_Exeunt PEMBROKE and STAFFORD_

But, ere I go, Hastings and Montague,  
Resolve my doubt. You twain, of all the rest,  
Are near to Warwick by blood and by alliance:  
Tell me if you love Warwick more than me?  
If it be so, then both depart to him;  
I rather wish you foes than hollow friends:  
But if you mind to hold your true obedience,  
Give me assurance with some friendly vow,  
That I may never have you in suspect.  

**MONTAGUE**  
So God help Montague as he proves true!  

**HASTINGS**  
And Hastings as he favours Edward's cause!  

**KING EDWARD IV**  
Now, brother Richard, will you stand by us?  

**GLOUCESTER**  
Ay, in despite of all that shall withstand you.  

**KING EDWARD IV**  
Why, so! then am I sure of victory.  
Now therefore let us hence; and lose no hour,  
Till we meet Warwick with his foreign power.  

_Exeunt_

### SCENE II. A plain in Warwickshire.

_Enter WARWICK and OXFORD, with French soldiers_

**WARWICK**  
Trust me, my lord, all hitherto goes well;  
The common people by numbers swarm to us.  

_Enter CLARENCE and SOMERSET_

But see where Somerset and Clarence come!  
Speak suddenly, my lords, are we all friends?  

**CLARENCE**  
Fear not that, my lord.  

**WARWICK**  
Then, gentle Clarence, welcome unto Warwick;  
And welcome, Somerset: I hold it cowardice  
To rest mistrustful where a noble heart  
Hath pawn'd an open hand in sign of love;  
Else might I think that Clarence, Edward's brother,  
Were but a feigned friend to our proceedings:  
But welcome, sweet Clarence; my daughter shall be thine.  
And now what rests but, in night's coverture,  
Thy brother being carelessly encamp'd,  
His soldiers lurking in the towns about,  
And but attended by a simple guard,  
We may surprise and take him at our pleasure?  
Our scouts have found the adventure very easy:  
That as Ulysses and stout Diomede  
With sleight and manhood stole to Rhesus' tents,  
And brought from thence the Thracian fatal steeds,  
So we, well cover'd with the night's black mantle,  
At unawares may beat down Edward's guard  
And seize himself; I say not, slaughter him,  
For I intend but only to surprise him.  
You that will follow me to this attempt,  
Applaud the name of Henry with your leader.  

_They all cry, 'Henry!'_

Why, then, let's on our way in silent sort:  
For Warwick and his friends, God and Saint George!  

_Exeunt_

### SCENE III. Edward's camp, near Warwick.

_Enter three Watchmen, to guard KING EDWARD IV 's tent_

**First Watchman**  
Come on, my masters, each man take his stand:  
The king by this is set him down to sleep.  

**Second Watchman**  
What, will he not to bed?  

**First Watchman**  
Why, no; for he hath made a solemn vow  
Never to lie and take his natural rest  
Till Warwick or himself be quite suppress'd.  

**Second Watchman**  
To-morrow then belike shall be the day,  
If Warwick be so near as men report.  

**Third Watchman**  
But say, I pray, what nobleman is that  
That with the king here resteth in his tent?  

**First Watchman**  
'Tis the Lord Hastings, the king's chiefest friend.  

**Third Watchman**  
O, is it so? But why commands the king  
That his chief followers lodge in towns about him,  
While he himself keeps in the cold field?  

**Second Watchman**  
'Tis the more honour, because more dangerous.  

**Third Watchman**  
Ay, but give me worship and quietness;  
I like it better than a dangerous honour.  
If Warwick knew in what estate he stands,  
'Tis to be doubted he would waken him.  

**First Watchman**  
Unless our halberds did shut up his passage.  

**Second Watchman**  
Ay, wherefore else guard we his royal tent,  
But to defend his person from night-foes?  

_Enter WARWICK, CLARENCE, OXFORD, SOMERSET, and French soldiers, silent all_

**WARWICK**  
This is his tent; and see where stand his guard.  
Courage, my masters! honour now or never!  
But follow me, and Edward shall be ours.  

**First Watchman**  
Who goes there?  

**Second Watchman**  
Stay, or thou diest!  

_WARWICK and the rest cry all, 'Warwick! Warwick!' and set upon the Guard,
who fly, crying, 'Arm! arm!' WARWICK and the rest following them_

_The drum playing and trumpet sounding, reenter WARWICK, SOMERSET, and the
rest, bringing KING EDWARD IV out in his gown, sitting in a chair. RICHARD and
HASTINGS fly over the stage_

**SOMERSET**  
What are they that fly there?  

**WARWICK**  
Richard and Hastings: let them go; here is The duke.  

**KING EDWARD IV**  
The duke! Why, Warwick, when we parted,  
Thou call'dst me king.  

**WARWICK**  
Ay, but the case is alter'd:  
When you disgraced me in my embassade,  
Then I degraded you from being king,  
And come now to create you Duke of York.  
Alas! how should you govern any kingdom,  
That know not how to use ambassadors,  
Nor how to be contented with one wife,  
Nor how to use your brothers brotherly,  
Nor how to study for the people's welfare,  
Nor how to shroud yourself from enemies?  

**KING EDWARD IV**  
Yea, brother of Clarence, are thou here too?  
Nay, then I see that Edward needs must down.  
Yet, Warwick, in despite of all mischance,  
Of thee thyself and all thy complices,  
Edward will always bear himself as king:  
Though fortune's malice overthrow my state,  
My mind exceeds the compass of her wheel.  

**WARWICK**  
Then, for his mind, be Edward England's king:  

_Takes off his crown_

But Henry now shall wear the English crown,  
And be true king indeed, thou but the shadow.  
My Lord of Somerset, at my request,  
See that forthwith Duke Edward be convey'd  
Unto my brother, Archbishop of York.  
When I have fought with Pembroke and his fellows,  
I'll follow you, and tell what answer  
Lewis and the Lady Bona send to him.  
Now, for a while farewell, good Duke of York.  

_They lead him out forcibly_

**KING EDWARD IV**  
What fates impose, that men must needs abide;  
It boots not to resist both wind and tide.  

_Exit, guarded_

**OXFORD**  
What now remains, my lords, for us to do  
But march to London with our soldiers?  

**WARWICK**  
Ay, that's the first thing that we have to do;  
To free King Henry from imprisonment  
And see him seated in the regal throne.  

_Exeunt_

### SCENE IV. London. The palace.

_Enter QUEEN ELIZABETH and RIVERS_

**RIVERS**  
Madam, what makes you in this sudden change?  

**QUEEN ELIZABETH**  
Why brother Rivers, are you yet to learn  
What late misfortune is befall'n King Edward?  

**RIVERS**  
What! loss of some pitch'd battle against Warwick?  

**QUEEN ELIZABETH**  
No, but the loss of his own royal person.  

**RIVERS**  
Then is my sovereign slain?  

**QUEEN ELIZABETH**  
Ay, almost slain, for he is taken prisoner,  
Either betray'd by falsehood of his guard  
Or by his foe surprised at unawares:  
And, as I further have to understand,  
Is new committed to the Bishop of York,  
Fell Warwick's brother and by that our foe.  

**RIVERS**  
These news I must confess are full of grief;  
Yet, gracious madam, bear it as you may:  
Warwick may lose, that now hath won the day.  

**QUEEN ELIZABETH**  
Till then fair hope must hinder life's decay.  
And I the rather wean me from despair  
For love of Edward's offspring in my womb:  
This is it that makes me bridle passion  
And bear with mildness my misfortune's cross;  
Ay, ay, for this I draw in many a tear  
And stop the rising of blood-sucking sighs,  
Lest with my sighs or tears I blast or drown  
King Edward's fruit, true heir to the English crown.  

**RIVERS**  
But, madam, where is Warwick then become?  

**QUEEN ELIZABETH**  
I am inform'd that he comes towards London,  
To set the crown once more on Henry's head:  
Guess thou the rest; King Edward's friends must down,  
But, to prevent the tyrant's violence,--  
For trust not him that hath once broken faith,--  
I'll hence forthwith unto the sanctuary,  
To save at least the heir of Edward's right:  
There shall I rest secure from force and fraud.  
Come, therefore, let us fly while we may fly:  
If Warwick take us we are sure to die.  

_Exeunt_

### SCENE V. A park near Middleham Castle In Yorkshire.

_Enter GLOUCESTER, HASTINGS, and STANLEY_

**GLOUCESTER**  
Now, my Lord Hastings and Sir William Stanley,  
Leave off to wonder why I drew you hither,  
Into this chiefest thicket of the park.  
Thus stands the case: you know our king, my brother,  
Is prisoner to the bishop here, at whose hands  
He hath good usage and great liberty,  
And, often but attended with weak guard,  
Comes hunting this way to disport himself.  
I have advertised him by secret means  
That if about this hour he make his way  
Under the colour of his usual game,  
He shall here find his friends with horse and men  
To set him free from his captivity.  

_Enter KING EDWARD IV and a Huntsman with him_

**Huntsman**  
This way, my lord; for this way lies the game.  

**KING EDWARD IV**  
Nay, this way, man: see where the huntsmen stand.  
Now, brother of Gloucester, Lord Hastings, and the rest,  
Stand you thus close, to steal the bishop's deer?  

**GLOUCESTER**  
Brother, the time and case requireth haste:  
Your horse stands ready at the park-corner.  

**KING EDWARD IV**  
But whither shall we then?  

**HASTINGS**  
To Lynn, my lord,  
And ship from thence to Flanders.  

**GLOUCESTER**  
Well guess'd, believe me; for that was my meaning.  

**KING EDWARD IV**  
Stanley, I will requite thy forwardness.  

**GLOUCESTER**  
But wherefore stay we? 'tis no time to talk.  

**KING EDWARD IV**  
Huntsman, what say'st thou? wilt thou go along?  

**Huntsman**  
Better do so than tarry and be hang'd.  

**GLOUCESTER**  
Come then, away; let's ha' no more ado.  

**KING EDWARD IV**  
Bishop, farewell: shield thee from Warwick's frown;  
And pray that I may repossess the crown.  

_Exeunt_

### SCENE VI. London. The Tower.

_Flourish. Enter KING HENRY VI, CLARENCE, WARWICK, SOMERSET, HENRY OF
RICHMOND, OXFORD, MONTAGUE, and Lieutenant of the Tower_

**KING HENRY VI**  
Master lieutenant, now that God and friends  
Have shaken Edward from the regal seat,  
And turn'd my captive state to liberty,  
My fear to hope, my sorrows unto joys,  
At our enlargement what are thy due fees?  

**Lieutenant**  
Subjects may challenge nothing of their sovereigns;  
But if an humble prayer may prevail,  
I then crave pardon of your majesty.  

**KING HENRY VI**  
For what, lieutenant? for well using me?  
Nay, be thou sure I'll well requite thy kindness,  
For that it made my imprisonment a pleasure;  
Ay, such a pleasure as incaged birds  
Conceive when after many moody thoughts  
At last by notes of household harmony  
They quite forget their loss of liberty.  
But, Warwick, after God, thou set'st me free,  
And chiefly therefore I thank God and thee;  
He was the author, thou the instrument.  
Therefore, that I may conquer fortune's spite  
By living low, where fortune cannot hurt me,  
And that the people of this blessed land  
May not be punish'd with my thwarting stars,  
Warwick, although my head still wear the crown,  
I here resign my government to thee,  
For thou art fortunate in all thy deeds.  

**WARWICK**  
Your grace hath still been famed for virtuous;  
And now may seem as wise as virtuous,  
By spying and avoiding fortune's malice,  
For few men rightly temper with the stars:  
Yet in this one thing let me blame your grace,  
For choosing me when Clarence is in place.  

**CLARENCE**  
No, Warwick, thou art worthy of the sway,  
To whom the heavens in thy nativity  
Adjudged an olive branch and laurel crown,  
As likely to be blest in peace and war;  
And therefore I yield thee my free consent.  

**WARWICK**  
And I choose Clarence only for protector.  

**KING HENRY VI**  
Warwick and Clarence give me both your hands:  
Now join your hands, and with your hands your hearts,  
That no dissension hinder government:  
I make you both protectors of this land,  
While I myself will lead a private life  
And in devotion spend my latter days,  
To sin's rebuke and my Creator's praise.  

**WARWICK**  
What answers Clarence to his sovereign's will?  

**CLARENCE**  
That he consents, if Warwick yield consent;  
For on thy fortune I repose myself.  

**WARWICK**  
Why, then, though loath, yet must I be content:  
We'll yoke together, like a double shadow  
To Henry's body, and supply his place;  
I mean, in bearing weight of government,  
While he enjoys the honour and his ease.  
And, Clarence, now then it is more than needful  
Forthwith that Edward be pronounced a traitor,  
And all his lands and goods be confiscate.  

**CLARENCE**  
What else? and that succession be determined.  

**WARWICK**  
Ay, therein Clarence shall not want his part.  

**KING HENRY VI**  
But, with the first of all your chief affairs,  
Let me entreat, for I command no more,  
That Margaret your queen and my son Edward  
Be sent for, to return from France with speed;  
For, till I see them here, by doubtful fear  
My joy of liberty is half eclipsed.  

**CLARENCE**  
It shall be done, my sovereign, with all speed.  

**KING HENRY VI**  
My Lord of Somerset, what youth is that,  
Of whom you seem to have so tender care?  

**SOMERSET**  
My liege, it is young Henry, earl of Richmond.  

**KING HENRY VI**  
Come hither, England's hope.  

_Lays his hand on his head_

If secret powers  
Suggest but truth to my divining thoughts,  
This pretty lad will prove our country's bliss.  
His looks are full of peaceful majesty,  
His head by nature framed to wear a crown,  
His hand to wield a sceptre, and himself  
Likely in time to bless a regal throne.  
Make much of him, my lords, for this is he  
Must help you more than you are hurt by me.  

_Enter a Post_

**WARWICK**  
What news, my friend?  

**Post**  
That Edward is escaped from your brother,  
And fled, as he hears since, to Burgundy.  

**WARWICK**  
Unsavoury news! but how made he escape?  

**Post**  
He was convey'd by Richard Duke of Gloucester  
And the Lord Hastings, who attended him  
In secret ambush on the forest side  
And from the bishop's huntsmen rescued him;  
For hunting was his daily exercise.  

**WARWICK**  
My brother was too careless of his charge.  
But let us hence, my sovereign, to provide  
A salve for any sore that may betide.  

_Exeunt all but SOMERSET, HENRY OF RICHMOND, and OXFORD_

**SOMERSET**  
My lord, I like not of this flight of Edward's;  
For doubtless Burgundy will yield him help,  
And we shall have more wars before 't be long.  
As Henry's late presaging prophecy  
Did glad my heart with hope of this young Richmond,  
So doth my heart misgive me, in these conflicts  
What may befall him, to his harm and ours:  
Therefore, Lord Oxford, to prevent the worst,  
Forthwith we'll send him hence to Brittany,  
Till storms be past of civil enmity.  

**OXFORD**  
Ay, for if Edward repossess the crown,  
'Tis like that Richmond with the rest shall down.  

**SOMERSET**  
It shall be so; he shall to Brittany.  
Come, therefore, let's about it speedily.  

_Exeunt_

### SCENE VII. Before York.

_Flourish. Enter KING EDWARD IV, GLOUCESTER, HASTINGS, and Soldiers_

**KING EDWARD IV**  
Now, brother Richard, Lord Hastings, and the rest,  
Yet thus far fortune maketh us amends,  
And says that once more I shall interchange  
My waned state for Henry's regal crown.  
Well have we pass'd and now repass'd the seas  
And brought desired help from Burgundy:  
What then remains, we being thus arrived  
From Ravenspurgh haven before the gates of York,  
But that we enter, as into our dukedom?  

**GLOUCESTER**  
The gates made fast! Brother, I like not this;  
For many men that stumble at the threshold  
Are well foretold that danger lurks within.  

**KING EDWARD IV**  
Tush, man, abodements must not now affright us:  
By fair or foul means we must enter in,  
For hither will our friends repair to us.  

**HASTINGS**  
My liege, I'll knock once more to summon them.  

_Enter, on the walls, the Mayor of York, and his Brethren_

**Mayor**  
My lords, we were forewarned of your coming,  
And shut the gates for safety of ourselves;  
For now we owe allegiance unto Henry.  

**KING EDWARD IV**  
But, master mayor, if Henry be your king,  
Yet Edward at the least is Duke of York.  

**Mayor**  
True, my good lord; I know you for no less.  

**KING EDWARD IV**  
Why, and I challenge nothing but my dukedom,  
As being well content with that alone.  

**GLOUCESTER**  
_[Aside]_  
But when the fox hath once got in his nose,  
He'll soon find means to make the body follow.  

**HASTINGS**  
Why, master mayor, why stand you in a doubt?  
Open the gates; we are King Henry's friends.  

**Mayor**  
Ay, say you so? the gates shall then be open'd.  

_They descend_

**GLOUCESTER**  
A wise stout captain, and soon persuaded!  

**HASTINGS**  
The good old man would fain that all were well,  
So 'twere not 'long of him; but being enter'd,  
I doubt not, I, but we shall soon persuade  
Both him and all his brothers unto reason.  

_Enter the Mayor and two Aldermen, below_

**KING EDWARD IV**  
So, master mayor: these gates must not be shut  
But in the night or in the time of war.  
What! fear not, man, but yield me up the keys;  

_Takes his keys_

For Edward will defend the town and thee,  
And all those friends that deign to follow me.  

_March. Enter MONTGOMERY, with drum and soldiers_

**GLOUCESTER**  
Brother, this is Sir John Montgomery,  
Our trusty friend, unless I be deceived.  

**KING EDWARD IV**  
Welcome, Sir John! But why come you in arms?  

**MONTAGUE**  
To help King Edward in his time of storm,  
As every loyal subject ought to do.  

**KING EDWARD IV**  
Thanks, good Montgomery; but we now forget  
Our title to the crown and only claim  
Our dukedom till God please to send the rest.  

**MONTAGUE**  
Then fare you well, for I will hence again:  
I came to serve a king and not a duke.  
Drummer, strike up, and let us march away.  

_The drum begins to march_

**KING EDWARD IV**  
Nay, stay, Sir John, awhi le, and we'll debate  
By what safe means the crown may be recover'd.  

**MONTAGUE**  
What talk you of debating? in few words,  
If you'll not here proclaim yourself our king,  
I'll leave you to your fortune and be gone  
To keep them back that come to succor you:  
Why shall we fight, if you pretend no title?  

**GLOUCESTER**  
Why, brother, wherefore stand you on nice points?  

**KING EDWARD IV**  
When we grow stronger, then we'll make our claim:  
Till then, 'tis wisdom to conceal our meaning.  

**HASTINGS**  
Away with scrupulous wit! now arms must rule.  

**GLOUCESTER**  
And fearless minds climb soonest unto crowns.  
Brother, we will proclaim you out of hand:  
The bruit thereof will bring you many friends.  

**KING EDWARD IV**  
Then be it as you will; for 'tis my right,  
And Henry but usurps the diadem.  

**MONTAGUE**  
Ay, now my sovereign speaketh like himself;  
And now will I be Edward's champion.  

**HASTINGS**  
Sound trumpet; Edward shall be here proclaim'd:  
Come, fellow-soldier, make thou proclamation.  

_Flourish_

**Soldier**  
Edward the Fourth, by the grace of God, king of  
England and France, and lord of Ireland, & c.  

**MONTAGUE**  
And whosoe'er gainsays King Edward's right,  
By this I challenge him to single fight.  

_Throws down his gauntlet_

**All**  
Long live Edward the Fourth!  

**KING EDWARD IV**  
Thanks, brave Montgomery; and thanks unto you all:  
If fortune serve me, I'll requite this kindness.  
Now, for this night, let's harbour here in York;  
And when the morning sun shall raise his car  
Above the border of this horizon,  
We'll forward towards Warwick and his mates;  
For well I wot that Henry is no soldier.  
Ah, froward Clarence! how evil it beseems thee  
To flatter Henry and forsake thy brother!  
Yet, as we may, we'll meet both thee and Warwick.  
Come on, brave soldiers: doubt not of the day,  
And, that once gotten, doubt not of large pay.  

_Exeunt_

### SCENE VIII. London. The palace.

_Flourish. Enter KING HENRY VI, WARWICK, MONTAGUE, CLARENCE, EXETER, and
OXFORD_

**WARWICK**  
What counsel, lords? Edward from Belgia,  
With hasty Germans and blunt Hollanders,  
Hath pass'd in safety through the narrow seas,  
And with his troops doth march amain to London;  
And many giddy people flock to him.  

**KING HENRY VI**  
Let's levy men, and beat him back again.  

**CLARENCE**  
A little fire is quickly trodden out;  
Which, being suffer'd, rivers cannot quench.  

**WARWICK**  
In Warwickshire I have true-hearted friends,  
Not mutinous in peace, yet bold in war;  
Those will I muster up: and thou, son Clarence,  
Shalt stir up in Suffolk, Norfolk, and in Kent,  
The knights and gentlemen to come with thee:  
Thou, brother Montague, in Buckingham,  
Northampton and in Leicestershire, shalt find  
Men well inclined to hear what thou command'st:  
And thou, brave Oxford, wondrous well beloved,  
In Oxfordshire shalt muster up thy friends.  
My sovereign, with the loving citizens,  
Like to his island girt in with the ocean,  
Or modest Dian circled with her nymphs,  
Shall rest in London till we come to him.  
Fair lords, take leave and stand not to reply.  
Farewell, my sovereign.  

**KING HENRY VI**  
Farewell, my Hector, and my Troy's true hope.  

**CLARENCE**  
In sign of truth, I kiss your highness' hand.  

**KING HENRY VI**  
Well-minded Clarence, be thou fortunate!  

**MONTAGUE**  
Comfort, my lord; and so I take my leave.  

**OXFORD**  
And thus I seal my truth, and bid adieu.  

**KING HENRY VI**  
Sweet Oxford, and my loving Montague,  
And all at once, once more a happy farewell.  

**WARWICK**  
Farewell, sweet lords: let's meet at Coventry.  

_Exeunt all but KING HENRY VI and EXETER_

**KING HENRY VI**  
Here at the palace I will rest awhile.  
Cousin of Exeter, what thinks your lordship?  
Methinks the power that Edward hath in field  
Should not be able to encounter mine.  

**EXETER**  
The doubt is that he will seduce the rest.  

**KING HENRY VI**  
That's not my fear; my meed hath got me fame:  
I have not stopp'd mine ears to their demands,  
Nor posted off their suits with slow delays;  
My pity hath been balm to heal their wounds,  
My mildness hath allay'd their swelling griefs,  
My mercy dried their water-flowing tears;  
I have not been desirous of their wealth,  
Nor much oppress'd them with great subsidies.  
Nor forward of revenge, though they much err'd:  
Then why should they love Edward more than me?  
No, Exeter, these graces challenge grace:  
And when the lion fawns upon the lamb,  
The lamb will never cease to follow him.  

_Shout within. 'A Lancaster! A Lancaster!'_

**EXETER**  
Hark, hark, my lord! what shouts are these?  

_Enter KING EDWARD IV, GLOUCESTER, and soldiers_

**KING EDWARD IV**  
Seize on the shame-faced Henry, bear him hence;  
And once again proclaim us King of England.  
You are the fount that makes small brooks to flow:  
Now stops thy spring; my sea sha$l suck them dry,  
And swell so much the higher by their ebb.  
Hence with him to the Tower; let him not speak.  

_Exeunt some with KING HENRY VI_

And, lords, towards Coventry bend we our course  
Where peremptory Warwick now remains:  
The sun shines hot; and, if we use delay,  
Cold biting winter mars our hoped-for hay.  

**GLOUCESTER**  
Away betimes, before his forces join,  
And take the great-grown traitor unawares:  
Brave warriors, march amain towards Coventry.  

_Exeunt_

# ACT V

### SCENE I. Coventry.

_Enter WARWICK, the Mayor of Coventry, two Messengers, and others upon the
walls_

**WARWICK**  
Where is the post that came from valiant Oxford?  
How far hence is thy lord, mine honest fellow?  

**First Messenger**  
By this at Dunsmore, marching hitherward.  

**WARWICK**  
How far off is our brother Montague?  
Where is the post that came from Montague?  

**Second Messenger**  
By this at Daintry, with a puissant troop.  

_Enter SIR JOHN SOMERVILLE_

**WARWICK**  
Say, Somerville, what says my loving son?  
And, by thy guess, how nigh is Clarence now?  

**SOMERSET**  
At Southam I did leave him with his forces,  
And do expect him here some two hours hence.  

_Drum heard_

**WARWICK**  
Then Clarence is at hand, I hear his drum.  

**SOMERSET**  
It is not his, my lord; here Southam lies:  
The drum your honour hears marcheth from Warwick.  

**WARWICK**  
Who should that be? belike, unlook'd-for friends.  

**SOMERSET**  
They are at hand, and you shall quickly know.  

_March: flourish. Enter KING EDWARD IV, GLOUCESTER, and soldiers_

**KING EDWARD IV**  
Go, trumpet, to the walls, and sound a parle.  

**GLOUCESTER**  
See how the surly Warwick mans the wall!  

**WARWICK**  
O unbid spite! is sportful Edward come?  
Where slept our scouts, or how are they seduced,  
That we could hear no news of his repair?  

**KING EDWARD IV**  
Now, Warwick, wilt thou ope the city gates,  
Speak gentle words and humbly bend thy knee,  
Call Edward king and at his hands beg mercy?  
And he shall pardon thee these outrages.  

**WARWICK**  
Nay, rather, wilt thou draw thy forces hence,  
Confess who set thee up and pluck'd thee own,  
Call Warwick patron and be penitent?  
And thou shalt still remain the Duke of York.  

**GLOUCESTER**  
I thought, at least, he would have said the king;  
Or did he make the jest against his will?  

**WARWICK**  
Is not a dukedom, sir, a goodly gift?  

**GLOUCESTER**  
Ay, by my faith, for a poor earl to give:  
I'll do thee service for so good a gift.  

**WARWICK**  
'Twas I that gave the kingdom to thy brother.  

**KING EDWARD IV**  
Why then 'tis mine, if but by Warwick's gift.  

**WARWICK**  
Thou art no Atlas for so great a weight:  
And weakling, Warwick takes his gift again;  
And Henry is my king, Warwick his subject.  

**KING EDWARD IV**  
But Warwick's king is Edward's prisoner:  
And, gallant Warwick, do but answer this:  
What is the body when the head is off?  

**GLOUCESTER**  
Alas, that Warwick had no more forecast,  
But, whiles he thought to steal the single ten,  
The king was slily finger'd from the deck!  
You left poor Henry at the Bishop's palace,  
And, ten to one, you'll meet him in the Tower.  

**EDWARD**  
'Tis even so; yet you are Warwick still.  

**GLOUCESTER**  
Come, Warwick, take the time; kneel down, kneel down:  
Nay, when? strike now, or else the iron cools.  

**WARWICK**  
I had rather chop this hand off at a blow,  
And with the other fling it at thy face,  
Than bear so low a sail, to strike to thee.  

**KING EDWARD IV**  
Sail how thou canst, have wind and tide thy friend,  
This hand, fast wound about thy coal-black hair  
Shall, whiles thy head is warm and new cut off,  
Write in the dust this sentence with thy blood,  
'Wind-changing Warwick now can change no more.'  

_Enter OXFORD, with drum and colours_

**WARWICK**  
O cheerful colours! see where Oxford comes!  

**OXFORD**  
Oxford, Oxford, for Lancaster!  

_He and his forces enter the city_

**GLOUCESTER**  
The gates are open, let us enter too.  

**KING EDWARD IV**  
So other foes may set upon our backs.  
Stand we in good array; for they no doubt  
Will issue out again and bid us battle:  
If not, the city being but of small defence,  
We'll quickly rouse the traitors in the same.  

**WARWICK**  
O, welcome, Oxford! for we want thy help.  

_Enter MONTAGUE with drum and colours_

**MONTAGUE**  
Montague, Montague, for Lancaster!  

_He and his forces enter the city_

**GLOUCESTER**  
Thou and thy brother both shall buy this treason  
Even with the dearest blood your bodies bear.  

**KING EDWARD IV**  
The harder match'd, the greater victory:  
My mind presageth happy gain and conquest.  

_Enter SOMERSET, with drum and colours_

**SOMERSET**  
Somerset, Somerset, for Lancaster!  

_He and his forces enter the city_

**GLOUCESTER**  
Two of thy name, both Dukes of Somerset,  
Have sold their lives unto the house of York;  
And thou shalt be the third if this sword hold.  

_Enter CLARENCE, with drum and colours_

**WARWICK**  
And lo, where George of Clarence sweeps along,  
Of force enough to bid his brother battle;  
With whom an upright zeal to right prevails  
More than the nature of a brother's love!  
Come, Clarence, come; thou wilt, if Warwick call.  

**CLARENCE**  
Father of Warwick, know you what this means?  

_Taking his red rose out of his hat_

Look here, I throw my infamy at thee  
I will not ruinate my father's house,  
Who gave his blood to lime the stones together,  
And set up Lancaster. Why, trow'st thou, Warwick,  
That Clarence is so harsh, so blunt, unnatural,  
To bend the fatal instruments of war  
Against his brother and his lawful king?  
Perhaps thou wilt object my holy oath:  
To keep that oath were more impiety  
Than Jephthah's, when he sacrificed his daughter.  
I am so sorry for my trespass made  
That, to deserve well at my brother's hands,  
I here proclaim myself thy mortal foe,  
With resolution, wheresoe'er I meet thee--  
As I will meet thee, if thou stir abroad--  
To plague thee for thy foul misleading me.  
And so, proud-hearted Warwick, I defy thee,  
And to my brother turn my blushing cheeks.  
Pardon me, Edward, I will make amends:  
And, Richard, do not frown upon my faults,  
For I will henceforth be no more unconstant.  

**KING EDWARD IV**  
Now welcome more, and ten times more beloved,  
Than if thou never hadst deserved our hate.  

**GLOUCESTER**  
Welcome, good Clarence; this is brotherlike.  

**WARWICK**  
O passing traitor, perjured and unjust!  

**KING EDWARD IV**  
What, Warwick, wilt thou leave the town and fight?  
Or shall we beat the stones about thine ears?  

**WARWICK**  
Alas, I am not coop'd here for defence!  
I will away towards Barnet presently,  
And bid thee battle, Edward, if thou darest.  

**KING EDWARD IV**  
Yes, Warwick, Edward dares, and leads the way.  
Lords, to the field; Saint George and victory!  

_Exeunt King Edward and his company. March. Warwick and his company follow_

### SCENE II. A field of battle near Barnet.

_Alarum and excursions. Enter KING EDWARD IV, bringing forth WARWICK
wounded_

**KING EDWARD IV**  
So, lie thou there: die thou, and die our fear;  
For Warwick was a bug that fear'd us all.  
Now, Montague, sit fast; I seek for thee,  
That Warwick's bones may keep thine company.  

_Exit_

**WARWICK**  
Ah, who is nigh? come to me, friend or foe,  
And tell me who is victor, York or Warwick?  
Why ask I that? my mangled body shows,  
My blood, my want of strength, my sick heart shows.  
That I must yield my body to the earth  
And, by my fall, the conquest to my foe.  
Thus yields the cedar to the axe's edge,  
Whose arms gave shelter to the princely eagle,  
Under whose shade the ramping lion slept,  
Whose top-branch overpeer'd Jove's spreading tree  
And kept low shrubs from winter's powerful wind.  
These eyes, that now are dimm'd with death's black veil,  
Have been as piercing as the mid-day sun,  
To search the secret treasons of the world:  
The wrinkles in my brows, now filled with blood,  
Were liken'd oft to kingly sepulchres;  
For who lived king, but I could dig his grave?  
And who durst mine when Warwick bent his brow?  
Lo, now my glory smear'd in dust and blood!  
My parks, my walks, my manors that I had.  
Even now forsake me, and of all my lands  
Is nothing left me but my body's length.  
Why, what is pomp, rule, reign, but earth and dust?  
And, live we how we can, yet die we must.  

_Enter OXFORD and SOMERSET_

**SOMERSET**  
Ah, Warwick, Warwick! wert thou as we are.  
We might recover all our loss again;  
The queen from France hath brought a puissant power:  
Even now we heard the news: ah, could'st thou fly!  

**WARWICK**  
Why, then I would not fly. Ah, Montague,  
If thou be there, sweet brother, take my hand.  
And with thy lips keep in my soul awhile!  
Thou lovest me not; for, brother, if thou didst,  
Thy tears would wash this cold congealed blood  
That glues my lips and will not let me speak.  
Come quickly, Montague, or I am dead.  

**SOMERSET**  
Ah, Warwick! Montague hath breathed his last;  
And to the latest gasp cried out for Warwick,  
And said 'Commend me to my valiant brother.'  
And more he would have said, and more he spoke,  
Which sounded like a clamour in a vault,  
That mought not be distinguished; but at last  
I well might hear, delivered with a groan,  
'O, farewell, Warwick!'  

**WARWICK**  
Sweet rest his soul! Fly, lords, and save yourselves;  
For Warwick bids you all farewell to meet in heaven.  

_Dies_

**OXFORD**  
Away, away, to meet the queen's great power!  

_Here they bear away his body. Exeunt_

### SCENE III. Another part of the field.

_Flourish. Enter KING EDWARD IV in triumph; with GLOUCESTER, CLARENCE, and
the rest_

**KING EDWARD IV**  
Thus far our fortune keeps an upward course,  
And we are graced with wreaths of victory.  
But, in the midst of this bright-shining day,  
I spy a black, suspicious, threatening cloud,  
That will encounter with our glorious sun,  
Ere he attain his easeful western bed:  
I mean, my lords, those powers that the queen  
Hath raised in Gallia have arrived our coast  
And, as we hear, march on to fight with us.  

**CLARENCE**  
A little gale will soon disperse that cloud  
And blow it to the source from whence it came:  
The very beams will dry those vapours up,  
For every cloud engenders not a storm.  

**GLOUCESTER**  
The queen is valued thirty thousand strong,  
And Somerset, with Oxford fled to her:  
If she have time to breathe be well assured  
Her faction will be full as strong as ours.  

**KING EDWARD IV**  
We are advertised by our loving friends  
That they do hold their course toward Tewksbury:  
We, having now the best at Barnet field,  
Will thither straight, for willingness rids way;  
And, as we march, our strength will be augmented  
In every county as we go along.  
Strike up the drum; cry 'Courage!' and away.  

_Exeunt_

### SCENE IV. Plains near Tewksbury.

_March. Enter QUEEN MARGARET, PRINCE EDWARD, SOMERSET, OXFORD, and soldiers_

**QUEEN MARGARET**  
Great lords, wise men ne'er sit and wail their loss,  
But cheerly seek how to redress their harms.  
What though the mast be now blown overboard,  
The cable broke, the holding-anchor lost,  
And half our sailors swallow'd in the flood?  
Yet lives our pilot still. Is't meet that he  
Should leave the helm and like a fearful lad  
With tearful eyes add water to the sea  
And give more strength to that which hath too much,  
Whiles, in his moan, the ship splits on the rock,  
Which industry and courage might have saved?  
Ah, what a shame! ah, what a fault were this!  
Say Warwick was our anchor; what of that?  
And Montague our topmost; what of him?  
Our slaughter'd friends the tackles; what of these?  
Why, is not Oxford here another anchor?  
And Somerset another goodly mast?  
The friends of France our shrouds and tacklings?  
And, though unskilful, why not Ned and I  
For once allow'd the skilful pilot's charge?  
We will not from the helm to sit and weep,  
But keep our course, though the rough wind say no,  
From shelves and rocks that threaten us with wreck.  
As good to chide the waves as speak them fair.  
And what is Edward but ruthless sea?  
What Clarence but a quicksand of deceit?  
And Richard but a ragged fatal rock?  
All these the enemies to our poor bark.  
Say you can swim; alas, 'tis but a while!  
Tread on the sand; why, there you quickly sink:  
Bestride the rock; the tide will wash you off,  
Or else you famish; that's a threefold death.  
This speak I, lords, to let you understand,  
If case some one of you would fly from us,  
That there's no hoped-for mercy with the brothers  
More than with ruthless waves, with sands and rocks.  
Why, courage then! what cannot be avoided  
'Twere childish weakness to lament or fear.  

**PRINCE EDWARD**  
Methinks a woman of this valiant spirit  
Should, if a coward heard her speak these words,  
Infuse his breast with magnanimity  
And make him, naked, foil a man at arms.  
I speak not this as doubting any here  
For did I but suspect a fearful man  
He should have leave to go away betimes,  
Lest in our need he might infect another  
And make him of like spirit to himself.  
If any such be here--as God forbid!--  
Let him depart before we need his help.  

**OXFORD**  
Women and children of so high a courage,  
And warriors faint! why, 'twere perpetual shame.  
O brave young prince! thy famous grandfather  
Doth live again in thee: long mayst thou live  
To bear his image and renew his glories!  

**SOMERSET**  
And he that will not fight for such a hope.  
Go home to bed, and like the owl by day,  
If he arise, be mock'd and wonder'd at.  

**QUEEN MARGARET**  
Thanks, gentle Somerset; sweet Oxford, thanks.  

**PRINCE EDWARD**  
And take his thanks that yet hath nothing else.  

_Enter a Messenger_

**Messenger**  
Prepare you, lords, for Edward is at hand.  
Ready to fight; therefore be resolute.  

**OXFORD**  
I thought no less: it is his policy  
To haste thus fast, to find us unprovided.  

**SOMERSET**  
But he's deceived; we are in readiness.  

**QUEEN MARGARET**  
This cheers my heart, to see your forwardness.  

**OXFORD**  
Here pitch our battle; hence we will not budge.  

_Flourish and march. Enter KING EDWARD IV, GLOUCESTER, CLARENCE, and
soldiers_

**KING EDWARD IV**  
Brave followers, yonder stands the thorny wood,  
Which, by the heavens' assistance and your strength,  
Must by the roots be hewn up yet ere night.  
I need not add more fuel to your fire,  
For well I wot ye blaze to burn them out  
Give signal to the fight, and to it, lords!  

**QUEEN MARGARET**  
Lords, knights, and gentlemen, what I should say  
My tears gainsay; for every word I speak,  
Ye see, I drink the water of mine eyes.  
Therefore, no more but this: Henry, your sovereign,  
Is prisoner to the foe; his state usurp'd,  
His realm a slaughter-house, his subjects slain,  
His statutes cancell'd and his treasure spent;  
And yonder is the wolf that makes this spoil.  
You fight in justice: then, in God's name, lords,  
Be valiant and give signal to the fight.  

_Alarum. Retreat. Excursions. Exeunt_

### SCENE V. Another part of the field.

_Flourish. Enter KING EDWARD IV, GLOUCESTER, CLARENCE, and soldiers; with
QUEEN MARGARET, OXFORD, and SOMERSET, prisoners_

**KING EDWARD IV**  
Now here a period of tumultuous broils.  
Away with Oxford to Hames Castle straight:  
For Somerset, off with his guilty head.  
Go, bear them hence; I will not hear them speak.  

**OXFORD**  
For my part, I'll not trouble thee with words.  

**SOMERSET**  
Nor I, but stoop with patience to my fortune.  

_Exeunt Oxford and Somerset, guarded_

**QUEEN MARGARET**  
So part we sadly in this troublous world,  
To meet with joy in sweet Jerusalem.  

**KING EDWARD IV**  
Is proclamation made, that who finds Edward  
Shall have a high reward, and he his life?  

**GLOUCESTER**  
It is: and lo, where youthful Edward comes!  

_Enter soldiers, with PRINCE EDWARD_

**KING EDWARD IV**  
Bring forth the gallant, let us hear him speak.  
What! can so young a thorn begin to prick?  
Edward, what satisfaction canst thou make  
For bearing arms, for stirring up my subjects,  
And all the trouble thou hast turn'd me to?  

**PRINCE EDWARD**  
Speak like a subject, proud ambitious York!  
Suppose that I am now my father's mouth;  
Resign thy chair, and where I stand kneel thou,  
Whilst I propose the selfsame words to thee,  
Which traitor, thou wouldst have me answer to.  

**QUEEN MARGARET**  
Ah, that thy father had been so resolved!  

**GLOUCESTER**  
That you might still have worn the petticoat,  
And ne'er have stol'n the breech from Lancaster.  

**PRINCE EDWARD**  
Let AEsop fable in a winter's night;  
His currish riddles sort not with this place.  

**GLOUCESTER**  
By heaven, brat, I'll plague ye for that word.  

**QUEEN MARGARET**  
Ay, thou wast born to be a plague to men.  

**GLOUCESTER**  
For God's sake, take away this captive scold.  

**PRINCE EDWARD**  
Nay, take away this scolding crookback rather.  

**KING EDWARD IV**  
Peace, wilful boy, or I will charm your tongue.  

**CLARENCE**  
Untutor'd lad, thou art too malapert.  

**PRINCE EDWARD**  
I know my duty; you are all undutiful:  
Lascivious Edward, and thou perjured George,  
And thou mis-shapen Dick, I tell ye all  
I am your better, traitors as ye are:  
And thou usurp'st my father's right and mine.  

**KING EDWARD IV**  
Take that, thou likeness of this railer here.  

_Stabs him_

**GLOUCESTER**  
Sprawl'st thou? take that, to end thy agony.  

_Stabs him_

**CLARENCE**  
And there's for twitting me with perjury.  

_Stabs him_

**QUEEN MARGARET**  
O, kill me too!  

**GLOUCESTER**  
Marry, and shall.  

_Offers to kill her_

**KING EDWARD IV**  
Hold, Richard, hold; for we have done too much.  

**GLOUCESTER**  
Why should she live, to fill the world with words?  

**KING EDWARD IV**  
What, doth she swoon? use means for her recovery.  

**GLOUCESTER**  
Clarence, excuse me to the king my brother;  
I'll hence to London on a serious matter:  
Ere ye come there, be sure to hear some news.  

**CLARENCE**  
What? what?  

**GLOUCESTER**  
The Tower, the Tower.  

_Exit_

**QUEEN MARGARET**  
O Ned, sweet Ned! speak to thy mother, boy!  
Canst thou not speak? O traitors! murderers!  
They that stabb'd Caesar shed no blood at all,  
Did not offend, nor were not worthy blame,  
If this foul deed were by to equal it:  
He was a man; this, in respect, a child:  
And men ne'er spend their fury on a child.  
What's worse than murderer, that I may name it?  
No, no, my heart will burst, and if I speak:  
And I will speak, that so my heart may burst.  
Butchers and villains! bloody cannibals!  
How sweet a plant have you untimely cropp'd!  
You have no children, butchers! if you had,  
The thought of them would have stirr'd up remorse:  
But if you ever chance to have a child,  
Look in his youth to have him so cut off  
As, deathmen, you have rid this sweet young prince!  

**KING EDWARD IV**  
Away with her; go, bear her hence perforce.  

**QUEEN MARGARET**  
Nay, never bear me hence, dispatch me here,  
Here sheathe thy sword, I'll pardon thee my death:  
What, wilt thou not? then, Clarence, do it thou.  

**CLARENCE**  
By heaven, I will not do thee so much ease.  

**QUEEN MARGARET**  
Good Clarence, do; sweet Clarence, do thou do it.  

**CLARENCE**  
Didst thou not hear me swear I would not do it?  

**QUEEN MARGARET**  
Ay, but thou usest to forswear thyself:  
'Twas sin before, but now 'tis charity.  
What, wilt thou not? Where is that devil's butcher,  
Hard-favour'd Richard? Richard, where art thou?  
Thou art not here: murder is thy alms-deed;  
Petitioners for blood thou ne'er put'st back.  

**KING EDWARD IV**  
Away, I say; I charge ye, bear her hence.  

**QUEEN MARGARET**  
So come to you and yours, as to this Prince!  

_Exit, led out forcibly_

**KING EDWARD IV**  
Where's Richard gone?  

**CLARENCE**  
To London, all in post; and, as I guess,  
To make a bloody supper in the Tower.  

**KING EDWARD IV**  
He's sudden, if a thing comes in his head.  
Now march we hence: discharge the common sort  
With pay and thanks, and let's away to London  
And see our gentle queen how well she fares:  
By this, I hope, she hath a son for me.  

_Exeunt_

### SCENE VI. London. The Tower.

_Enter KING HENRY VI and GLOUCESTER, with the Lieutenant, on the walls_

**GLOUCESTER**  
Good day, my lord. What, at your book so hard?  

**KING HENRY VI**  
Ay, my good lord:--my lord, I should say rather;  
'Tis sin to flatter; 'good' was little better:  
'Good Gloucester' and 'good devil' were alike,  
And both preposterous; therefore, not 'good lord.'  

**GLOUCESTER**  
Sirrah, leave us to ourselves: we must confer.  

_Exit Lieutenant_

**KING HENRY VI**  
So flies the reckless shepherd from the wolf;  
So first the harmless sheep doth yield his fleece  
And next his throat unto the butcher's knife.  
What scene of death hath Roscius now to act?  

**GLOUCESTER**  
Suspicion always haunts the guilty mind;  
The thief doth fear each bush an officer.  

**KING HENRY VI**  
The bird that hath been limed in a bush,  
With trembling wings misdoubteth every bush;  
And I, the hapless male to one sweet bird,  
Have now the fatal object in my eye  
Where my poor young was limed, was caught and kill'd.  

**GLOUCESTER**  
Why, what a peevish fool was that of Crete,  
That taught his son the office of a fowl!  
An yet, for all his wings, the fool was drown'd.  

**KING HENRY VI**  
I, Daedalus; my poor boy, Icarus;  
Thy father, Minos, that denied our course;  
The sun that sear'd the wings of my sweet boy  
Thy brother Edward, and thyself the sea  
Whose envious gulf did swallow up his life.  
Ah, kill me with thy weapon, not with words!  
My breast can better brook thy dagger's point  
Than can my ears that tragic history.  
But wherefore dost thou come? is't for my life?  

**GLOUCESTER**  
Think'st thou I am an executioner?  

**KING HENRY VI**  
A persecutor, I am sure, thou art:  
If murdering innocents be executing,  
Why, then thou art an executioner.  

**GLOUCESTER**  
Thy son I kill'd for his presumption.  

**KING HENRY VI**  
Hadst thou been kill'd when first thou didst presume,  
Thou hadst not lived to kill a son of mine.  
And thus I prophesy, that many a thousand,  
Which now mistrust no parcel of my fear,  
And many an old man's sigh and many a widow's,  
And many an orphan's water-standing eye--  
Men for their sons, wives for their husbands,  
And orphans for their parents timeless death--  
Shall rue the hour that ever thou wast born.  
The owl shriek'd at thy birth,--an evil sign;  
The night-crow cried, aboding luckless time;  
Dogs howl'd, and hideous tempest shook down trees;  
The raven rook'd her on the chimney's top,  
And chattering pies in dismal discords sung.  
Thy mother felt more than a mother's pain,  
And, yet brought forth less than a mother's hope,  
To wit, an indigested and deformed lump,  
Not like the fruit of such a goodly tree.  
Teeth hadst thou in thy head when thou wast born,  
To signify thou camest to bite the world:  
And, if the rest be true which I have heard,  
Thou camest--  

**GLOUCESTER**  
I'll hear no more: die, prophet in thy speech:  

_Stabs him_

For this amongst the rest, was I ordain'd.  

**KING HENRY VI**  
Ay, and for much more slaughter after this.  
God forgive my sins, and pardon thee!  

_Dies_

**GLOUCESTER**  
What, will the aspiring blood of Lancaster  
Sink in the ground? I thought it would have mounted.  
See how my sword weeps for the poor king's death!  
O, may such purple tears be alway shed  
From those that wish the downfall of our house!  
If any spark of life be yet remaining,  
Down, down to hell; and say I sent thee thither:  

_Stabs him again_

I, that have neither pity, love, nor fear.  
Indeed, 'tis true that Henry told me of;  
For I have often heard my mother say  
I came into the world with my legs forward:  
Had I not reason, think ye, to make haste,  
And seek their ruin that usurp'd our right?  
The midwife wonder'd and the women cried  
'O, Jesus bless us, he is born with teeth!'  
And so I was; which plainly signified  
That I should snarl and bite and play the dog.  
Then, since the heavens have shaped my body so,  
Let hell make crook'd my mind to answer it.  
I have no brother, I am like no brother;  
And this word 'love,' which graybeards call divine,  
Be resident in men like one another  
And not in me: I am myself alone.  
Clarence, beware; thou keep'st me from the light:  
But I will sort a pitchy day for thee;  
For I will buz abroad such prophecies  
That Edward shall be fearful of his life,  
And then, to purge his fear, I'll be thy death.  
King Henry and the prince his son are gone:  
Clarence, thy turn is next, and then the rest,  
Counting myself but bad till I be best.  
I'll throw thy body in another room  
And triumph, Henry, in thy day of doom.  

_Exit, with the body_

### SCENE VII. London. The palace.

_Flourish. Enter KING EDWARD IV, QUEEN ELIZABETH, CLARENCE, GLOUCESTER,
HASTINGS, a Nurse with the young Prince, and Attendants_

**KING EDWARD IV**  
Once more we sit in England's royal throne,  
Re-purchased with the blood of enemies.  
What valiant foemen, like to autumn's corn,  
Have we mow'd down, in tops of all their pride!  
Three Dukes of Somerset, threefold renown'd  
For hardy and undoubted champions;  
Two Cliffords, as the father and the son,  
And two Northumberlands; two braver men  
Ne'er spurr'd their coursers at the trumpet's sound;  
With them, the two brave bears, Warwick and Montague,  
That in their chains fetter'd the kingly lion  
And made the forest tremble when they roar'd.  
Thus have we swept suspicion from our seat  
And made our footstool of security.  
Come hither, Bess, and let me kiss my boy.  
Young Ned, for thee, thine uncles and myself  
Have in our armours watch'd the winter's night,  
Went all afoot in summer's scalding heat,  
That thou mightst repossess the crown in peace;  
And of our labours thou shalt reap the gain.  

**GLOUCESTER**  
_[Aside]_  
I'll blast his harvest, if your head were laid;  
For yet I am not look'd on in the world.  
This shoulder was ordain'd so thick to heave;  
And heave it shall some weight, or break my back:  
Work thou the way,--and thou shalt execute.  

**KING EDWARD IV**  
Clarence and Gloucester, love my lovely queen;  
And kiss your princely nephew, brothers both.  

**CLARENCE**  
The duty that I owe unto your majesty  
I seal upon the lips of this sweet babe.  

**QUEEN ELIZABETH**  
Thanks, noble Clarence; worthy brother, thanks.  

**GLOUCESTER**  
And, that I love the tree from whence thou sprang'st,  
Witness the loving kiss I give the fruit.  

_Aside_

And cried 'all hail!' when as he meant all harm.  

**KING EDWARD IV**  
Now am I seated as my soul delights,  
Having my country's peace and brothers' loves.  

**CLARENCE**  
What will your grace have done with Margaret?  
Reignier, her father, to the king of France  
Hath pawn'd the Sicils and Jerusalem,  
And hither have they sent it for her ransom.  

**KING EDWARD IV**  
Away with her, and waft her hence to France.  
And now what rests but that we spend the time  
With stately triumphs, mirthful comic shows,  
Such as befits the pleasure of the court?  
Sound drums and trumpets! farewell sour annoy!  
For here, I hope, begins our lasting joy.  

_Exeunt_
